DataTransfer

Struct DataTransfer 

pub struct DataTransfer<'a> { /* private fields */ }

Implementations

Source

impl<'a> DataTransfer<'a>

pub async fn transfer_flow_files( &self, port_id: &str, transaction_id: &str, ) -> Result<Vec<u8>, NifiError>

Transfer FlowFiles from the output port

Calls GET /nifi-api/data-transfer/output-ports/{portId}/transactions/{transactionId}/flow-files.

Parameters
  • port_id: The output port id.
  • transaction_id: The transaction id.
Returns
  • 200: There is no flow file to return.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
  • 503: NiFi instance is not ready for serving request, or temporarily overloaded. Retrying the same request later may be successful
Permissions

Requires Write - /data-transfer/output-ports/{uuid}.

pub async fn transfer_flow_files_stream( &self, port_id: &str, transaction_id: &str, ) -> Result<BytesStream, NifiError>

Streaming variant: yields body chunks as they arrive instead of buffering the whole response.

Transfer FlowFiles from the output port

Calls GET /nifi-api/data-transfer/output-ports/{portId}/transactions/{transactionId}/flow-files.

Parameters
  • port_id: The output port id.
  • transaction_id: The transaction id.
Returns
  • 200: There is no flow file to return.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
  • 503: NiFi instance is not ready for serving request, or temporarily overloaded. Retrying the same request later may be successful
Permissions

Requires Write - /data-transfer/output-ports/{uuid}.

pub async fn receive_flow_files( &self, port_id: &str, transaction_id: &str, data: Vec<u8>, ) -> Result<String, NifiError>

Transfer FlowFiles to the input port

Calls POST /nifi-api/data-transfer/input-ports/{portId}/transactions/{transactionId}/flow-files.

Parameters
  • port_id: The input port id.
  • transaction_id: The transaction id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
  • 503: NiFi instance is not ready for serving request, or temporarily overloaded. Retrying the same request later may be successful
Permissions

Requires Write - /data-transfer/input-ports/{uuid}.

pub async fn create_port_transaction( &self, port_type: &str, port_id: &str, ) -> Result<TransactionResultEntity, NifiError>

Create a transaction to the specified output port or input port

Calls POST /nifi-api/data-transfer/{portType}/{portId}/transactions.

Parameters
  • port_type: The port type.
  • port_id: The input or output port id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
  • 503: NiFi instance is not ready for serving request, or temporarily overloaded. Retrying the same request later may be successful
Permissions

Requires Write - /data-transfer/{component-type}/{uuid}.

pub async fn extend_input_port_transaction_t_t_l( &self, port_id: &str, transaction_id: &str, ) -> Result<TransactionResultEntity, NifiError>

Extend transaction TTL

Calls PUT /nifi-api/data-transfer/input-ports/{portId}/transactions/{transactionId}.

Parameters
  • port_id: The input port id.
  • transaction_id: The transaction id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /data-transfer/input-ports/{uuid}.

pub async fn extend_output_port_transaction_t_t_l( &self, port_id: &str, transaction_id: &str, ) -> Result<TransactionResultEntity, NifiError>

Extend transaction TTL

Calls PUT /nifi-api/data-transfer/output-ports/{portId}/transactions/{transactionId}.

Parameters
  • port_id: The output port id.
  • transaction_id: The transaction id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
  • 503: NiFi instance is not ready for serving request, or temporarily overloaded. Retrying the same request later may be successful
Permissions

Requires Write - /data-transfer/output-ports/{uuid}.

pub async fn commit_input_port_transaction( &self, port_id: &str, transaction_id: &str, response_code: i32, data: Vec<u8>, ) -> Result<TransactionResultEntity, NifiError>

Commit or cancel the specified transaction

Calls DELETE /nifi-api/data-transfer/input-ports/{portId}/transactions/{transactionId}.

Parameters
  • port_id: The input port id.
  • transaction_id: The transaction id.
  • response_code: The response code. Available values are BAD_CHECKSUM(19), CONFIRM_TRANSACTION(12) or CANCEL_TRANSACTION(15).
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
  • 503: NiFi instance is not ready for serving request, or temporarily overloaded. Retrying the same request later may be successful
Permissions

Requires Write - /data-transfer/input-ports/{uuid}.

pub async fn commit_output_port_transaction( &self, port_id: &str, transaction_id: &str, response_code: i32, checksum: &str, data: Vec<u8>, ) -> Result<TransactionResultEntity, NifiError>

Commit or cancel the specified transaction

Calls DELETE /nifi-api/data-transfer/output-ports/{portId}/transactions/{transactionId}.

Parameters
  • port_id: The output port id.
  • transaction_id: The transaction id.
  • response_code: The response code. Available values are CONFIRM_TRANSACTION(12) or CANCEL_TRANSACTION(15).
  • checksum: A checksum calculated at client side using CRC32 to check flow file content integrity. It must match with the value calculated at server side.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
  • 503: NiFi instance is not ready for serving request, or temporarily overloaded. Retrying the same request later may be successful
Permissions

Requires Write - /data-transfer/output-ports/{uuid}.