ProcessGroups

Struct ProcessGroups 

pub struct ProcessGroups<'a> { /* private fields */ }

Implementations

Source

impl<'a> ProcessGroups<'a>

pub async fn get_replace_process_group_request( &self, id: &str, ) -> Result<ProcessGroupReplaceRequestEntity, NifiError>

Returns the Replace Request with the given ID

Returns the Replace Request with the given ID. Once a Replace Request has been created by performing a POST to /process-groups/{id}/replace-requests, that request can subsequently be retrieved via this endpoint, and the request that is fetched will contain the updated state, such as percent complete, the current state of the request, and any failures. Note: This endpoint is subject to change as NiFi and it’s REST API evolve.

Calls GET /nifi-api/process-groups/replace-requests/{id}.

Parameters
  • id: The ID of the Replace Request
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Only the user that submitted the request can get it.

pub async fn get_process_group( &self, id: &str, ) -> Result<ProcessGroupEntity, NifiError>

Gets a process group

Calls GET /nifi-api/process-groups/{id}.

Parameters
  • id: The process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /process-groups/{uuid}.

pub async fn get_connections( &self, id: &str, ) -> Result<ConnectionsEntity, NifiError>

Gets all connections

Calls GET /nifi-api/process-groups/{id}/connections.

Parameters
  • id: The process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /process-groups/{uuid}.

pub async fn export_process_group( &self, id: &str, include_referenced_services: Option<bool>, ) -> Result<Value, NifiError>

Gets a process group for download

Calls GET /nifi-api/process-groups/{id}/download.

Parameters
  • id: The process group id.
  • include_referenced_services: If referenced services from outside the target group should be included
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /process-groups/{uuid}.

pub async fn get_drop_all_flowfiles_request( &self, id: &str, drop_request_id: &str, ) -> Result<DropRequestDto, NifiError>

Gets the current status of a drop all FlowFiles request.

Calls GET /nifi-api/process-groups/{id}/empty-all-connections-requests/{drop-request-id}.

Parameters
  • id: The process group id.
  • drop_request_id: The drop request id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Read - /process-groups/{uuid} - For this and all encapsulated process groups
  • Write Source Data - /data/{component-type}/{uuid} - For all encapsulated connections
pub async fn get_funnels(&self, id: &str) -> Result<FunnelsEntity, NifiError>

Gets all funnels

Calls GET /nifi-api/process-groups/{id}/funnels.

Parameters
  • id: The process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /process-groups/{uuid}.

pub async fn get_input_ports( &self, id: &str, ) -> Result<InputPortsEntity, NifiError>

Gets all input ports

Calls GET /nifi-api/process-groups/{id}/input-ports.

Parameters
  • id: The process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /process-groups/{uuid}.

pub async fn get_labels(&self, id: &str) -> Result<LabelsEntity, NifiError>

Gets all labels

Calls GET /nifi-api/process-groups/{id}/labels.

Parameters
  • id: The process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /process-groups/{uuid}.

pub async fn get_local_modifications( &self, id: &str, ) -> Result<FlowComparisonEntity, NifiError>

Gets a list of local modifications to the Process Group since it was last synchronized with the Flow Registry

Calls GET /nifi-api/process-groups/{id}/local-modifications.

Parameters
  • id: The process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Read - /process-groups/{uuid}
  • Read - /{component-type}/{uuid} - For all encapsulated components
pub async fn get_output_ports( &self, id: &str, ) -> Result<OutputPortsEntity, NifiError>

Gets all output ports

Calls GET /nifi-api/process-groups/{id}/output-ports.

Parameters
  • id: The process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /process-groups/{uuid}.

pub async fn get_process_groups( &self, id: &str, ) -> Result<ProcessGroupsEntity, NifiError>

Gets all process groups

Calls GET /nifi-api/process-groups/{id}/process-groups.

Parameters
  • id: The process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /process-groups/{uuid}.

pub async fn get_processors( &self, id: &str, include_descendant_groups: Option<bool>, ) -> Result<ProcessorsEntity, NifiError>

Gets all processors

Calls GET /nifi-api/process-groups/{id}/processors.

Parameters
  • id: The process group id.
  • include_descendant_groups: Whether or not to include processors from descendant process groups
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /process-groups/{uuid}.

pub async fn get_remote_process_groups( &self, id: &str, ) -> Result<RemoteProcessGroupsEntity, NifiError>

Gets all remote process groups

Calls GET /nifi-api/process-groups/{id}/remote-process-groups.

Parameters
  • id: The process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /process-groups/{uuid}.

pub async fn create_connection( &self, id: &str, body: &ConnectionEntity, ) -> Result<ConnectionEntity, NifiError>

Creates a connection

Calls POST /nifi-api/process-groups/{id}/connections.

Parameters
  • id: The process group id.
  • body: The connection configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Write - /process-groups/{uuid}
  • Write Source - /{component-type}/{uuid}
  • Write Destination - /{component-type}/{uuid}
pub async fn create_controller_service( &self, id: &str, body: &ControllerServiceEntity, ) -> Result<ControllerServiceEntity, NifiError>

Creates a new controller service

Calls POST /nifi-api/process-groups/{id}/controller-services.

Parameters
  • id: The process group id.
  • body: The controller service configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Write - /process-groups/{uuid}
  • Read - any referenced Controller Services - /controller-services/{uuid}
  • Write - if the Controller Service is restricted - /restricted-components
pub async fn copy( &self, id: &str, body: &CopyRequestEntity, ) -> Result<CopyResponseEntity, NifiError>

Generates a copy response for the given copy request

Calls POST /nifi-api/process-groups/{id}/copy.

Parameters
  • id: The process group id.
  • body: The request including the components to be copied from the specified Process Group.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /{component-type}/{uuid} - For all encapsulated components.

pub async fn create_empty_all_connections_request( &self, id: &str, ) -> Result<DropRequestDto, NifiError>

Creates a request to drop all FlowFiles of all connection queues in this process group.

Calls POST /nifi-api/process-groups/{id}/empty-all-connections-requests.

Parameters
  • id: The process group id.
Returns
  • 202: The request has been accepted. An HTTP response header will contain the URI where the status can be polled.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Read - /process-groups/{uuid} - For this and all encapsulated process groups
  • Write Source Data - /data/{component-type}/{uuid} - For all encapsulated connections
pub async fn create_funnel( &self, id: &str, body: &FunnelEntity, ) -> Result<FunnelEntity, NifiError>

Creates a funnel

Calls POST /nifi-api/process-groups/{id}/funnels.

Parameters
  • id: The process group id.
  • body: The funnel configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /process-groups/{uuid}.

pub async fn create_input_port( &self, id: &str, body: &PortEntity, ) -> Result<PortEntity, NifiError>

Creates an input port

Calls POST /nifi-api/process-groups/{id}/input-ports.

Parameters
  • id: The process group id.
  • body: The input port configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /process-groups/{uuid}.

pub async fn create_label( &self, id: &str, body: &LabelEntity, ) -> Result<LabelEntity, NifiError>

Creates a label

Calls POST /nifi-api/process-groups/{id}/labels.

Parameters
  • id: The process group id.
  • body: The label configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /process-groups/{uuid}.

pub async fn create_output_port( &self, id: &str, body: &PortEntity, ) -> Result<PortEntity, NifiError>

Creates an output port

Calls POST /nifi-api/process-groups/{id}/output-ports.

Parameters
  • id: The process group id.
  • body: The output port configuration.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /process-groups/{uuid}.

pub async fn create_process_group( &self, id: &str, parameter_context_handling_strategy: Option<ParameterContextHandlingStrategy>, body: &ProcessGroupEntity, ) -> Result<ProcessGroupEntity, NifiError>

Creates a process group

Calls POST /nifi-api/process-groups/{id}/process-groups.

Parameters
  • id: The process group id.
  • parameter_context_handling_strategy: Handling Strategy controls whether to keep or replace Parameter Contexts
  • body: The process group configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /process-groups/{uuid}.

pub async fn import_process_group( &self, id: &str, body: &ProcessGroupUploadEntity, ) -> Result<ProcessGroupEntity, NifiError>

Imports a specified process group

Calls POST /nifi-api/process-groups/{id}/process-groups/import.

Parameters
  • id: The process group id.
  • body: The Process Group Upload import details
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /process-groups/{uuid}.

pub async fn upload_process_group( &self, id: &str, client_id: &str, disconnected_node_acknowledged: Option<bool>, group_name: &str, position_x: f64, position_y: f64, filename: &str, data: Vec<u8>, ) -> Result<ProcessGroupEntity, NifiError>

Uploads a versioned flow definition and creates a process group

Calls POST /nifi-api/process-groups/{id}/process-groups/upload.

Parameters
  • id: The process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /process-groups/{uuid}.

pub async fn create_processor( &self, id: &str, body: &ProcessorEntity, ) -> Result<ProcessorEntity, NifiError>

Creates a new processor

Calls POST /nifi-api/process-groups/{id}/processors.

Parameters
  • id: The process group id.
  • body: The processor configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Write - /process-groups/{uuid}
  • Read - any referenced Controller Services - /controller-services/{uuid}
  • Write - if the Processor is restricted - /restricted-components
pub async fn create_remote_process_group( &self, id: &str, body: &RemoteProcessGroupEntity, ) -> Result<RemoteProcessGroupEntity, NifiError>

Creates a new process group

Calls POST /nifi-api/process-groups/{id}/remote-process-groups.

Parameters
  • id: The process group id.
  • body: The remote process group configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /process-groups/{uuid}.

pub async fn initiate_replace_process_group( &self, id: &str, body: &ProcessGroupImportEntity, ) -> Result<ProcessGroupReplaceRequestEntity, NifiError>

Initiate the Replace Request of a Process Group with the given ID

This will initiate the action of replacing a process group with the given process group. This can be a lengthy process, as it will stop any Processors and disable any Controller Services necessary to perform the action and then restart them. As a result, the endpoint will immediately return a ProcessGroupReplaceRequestEntity, and the process of replacing the flow will occur asynchronously in the background. The client may then periodically poll the status of the request by issuing a GET request to /process-groups/replace-requests/{requestId}. Once the request is completed, the client is expected to issue a DELETE request to /process-groups/replace-requests/{requestId}. Note: This endpoint is subject to change as NiFi and it’s REST API evolve.

Calls POST /nifi-api/process-groups/{id}/replace-requests.

Parameters
  • id: The process group id.
  • body: The process group replace request entity
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Read - /process-groups/{uuid}
  • Write - /process-groups/{uuid}
  • Read - /{component-type}/{uuid} - For all encapsulated components
  • Write - /{component-type}/{uuid} - For all encapsulated components
  • Write - if the snapshot contains any restricted components - /restricted-components
  • Read - /parameter-contexts/{uuid} - For any Parameter Context that is referenced by a Property that is changed, added, or removed
pub async fn copy_snippet( &self, id: &str, body: &CopySnippetRequestEntity, ) -> Result<FlowDto, NifiError>

Copies a snippet and discards it.

Calls POST /nifi-api/process-groups/{id}/snippet-instance.

Parameters
  • id: The process group id.
  • body: The copy snippet request.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Write - /process-groups/{uuid}
  • Read - /{component-type}/{uuid} - For each component in the snippet and their descendant components
  • Write - if the snippet contains any restricted Processors - /restricted-components
pub async fn update_process_group( &self, id: &str, body: &ProcessGroupEntity, ) -> Result<ProcessGroupEntity, NifiError>

Updates a process group

Calls PUT /nifi-api/process-groups/{id}.

Parameters
  • id: The process group id.
  • body: The process group configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /process-groups/{uuid}.

pub async fn replace_process_group( &self, id: &str, body: &ProcessGroupImportEntity, ) -> Result<ProcessGroupImportEntity, NifiError>

Replace Process Group contents with the given ID with the specified Process Group contents

This endpoint is used for replication within a cluster, when replacing a flow with a new flow. It expects that the flow beingreplaced is not under version control and that the given snapshot will not modify any Processor that is currently running or any Controller Service that is enabled. Note: This endpoint is subject to change as NiFi and it’s REST API evolve.

Calls PUT /nifi-api/process-groups/{id}/flow-contents.

Parameters
  • id: The process group id.
  • body: The process group replace request entity.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Read - /process-groups/{uuid}
  • Write - /process-groups/{uuid}
pub async fn paste( &self, id: &str, body: &PasteRequestEntity, ) -> Result<PasteResponseEntity, NifiError>

Pastes into the specified process group

Calls PUT /nifi-api/process-groups/{id}/paste.

Parameters
  • id: The process group id.
  • body: The request including the components to be pasted into the specified Process Group.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /process-groups/{uuid}.

pub async fn delete_replace_process_group_request( &self, id: &str, disconnected_node_acknowledged: Option<bool>, ) -> Result<ProcessGroupReplaceRequestEntity, NifiError>

Deletes the Replace Request with the given ID

Deletes the Replace Request with the given ID. After a request is created via a POST to /process-groups/{id}/replace-requests, it is expected that the client will properly clean up the request by DELETE’ing it, once the Replace process has completed. If the request is deleted before the request completes, then the Replace request will finish the step that it is currently performing and then will cancel any subsequent steps. Note: This endpoint is subject to change as NiFi and it’s REST API evolve.

Calls DELETE /nifi-api/process-groups/replace-requests/{id}.

Parameters
  • id: The ID of the Update Request
  • disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Only the user that submitted the request can remove it.

pub async fn remove_process_group( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<ProcessGroupEntity, NifiError>

Deletes a process group

Calls DELETE /nifi-api/process-groups/{id}.

Parameters
  • id: The process group id.
  • version: The revision is used to verify the client is working with the latest version of the flow.
  • client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.
  • disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Write - /process-groups/{uuid}
  • Write - Parent Process Group - /process-groups/{uuid}
  • Read - any referenced Controller Services by any encapsulated components - /controller-services/{uuid}
  • Write - /{component-type}/{uuid} - For all encapsulated components
pub async fn remove_drop_request( &self, id: &str, drop_request_id: &str, ) -> Result<DropRequestDto, NifiError>

Cancels and/or removes a request to drop all FlowFiles.

Calls DELETE /nifi-api/process-groups/{id}/empty-all-connections-requests/{drop-request-id}.

Parameters
  • id: The process group id.
  • drop_request_id: The drop request id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Read - /process-groups/{uuid} - For this and all encapsulated process groups
  • Write Source Data - /data/{component-type}/{uuid} - For all encapsulated connections