#[non_exhaustive]pub enum VersionResolutionStrategy {
Strict,
Closest,
Latest,
}Expand description
Controls how the dynamic client resolves a detected NiFi server version to a supported client version.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Strict
Require an exact major.minor match; return NifiError::UnsupportedVersion otherwise.
Closest
Use the supported version with the nearest minor version within the same major. Ties go to the lower version.
Latest
Use the highest supported minor version within the same major.