DynamicControllerApi

Struct DynamicControllerApi 

pub struct DynamicControllerApi<'a> { /* private fields */ }
Dynamic dispatch wrapper for the Controller API.

Implementations

Source

impl<'a> DynamicControllerApi<'a>

pub async fn analyze_flow_analysis_rule_configuration( &self, id: &str, body: &Value, ) -> Result<ConfigurationAnalysisDto, NifiError>

Performs analysis of the component’s configuration, providing information about which attributes are referenced.

pub async fn analyze_flow_registry_client_configuration( &self, id: &str, body: &Value, ) -> Result<ConfigurationAnalysisDto, NifiError>

Performs analysis of the component’s configuration, providing information about which attributes are referenced.

pub async fn clear_flow_analysis_rule_bulletins( &self, id: &str, body: &Value, ) -> Result<ClearBulletinsResultEntity, NifiError>

Clears bulletins for a flow analysis rule

pub async fn clear_parameter_provider_bulletins( &self, id: &str, body: &Value, ) -> Result<ClearBulletinsResultEntity, NifiError>

Clears bulletins for a parameter provider

pub async fn clear_registry_client_bulletins( &self, id: &str, body: &Value, ) -> Result<ClearBulletinsResultEntity, NifiError>

Clears bulletins for a registry client

pub async fn clear_state( &self, id: &str, body: &Value, ) -> Result<ComponentStateDto, NifiError>

Clears the state for a flow analysis rule

pub async fn create_bulletin( &self, body: &Value, ) -> Result<BulletinEntity, NifiError>

Creates a new bulletin

pub async fn create_controller_service( &self, body: &Value, ) -> Result<ControllerServiceEntity, NifiError>

Creates a new controller service

pub async fn create_flow_analysis_rule( &self, body: &Value, ) -> Result<FlowAnalysisRuleEntity, NifiError>

Creates a new flow analysis rule

pub async fn create_flow_registry_client( &self, body: &Value, ) -> Result<FlowRegistryClientEntity, NifiError>

Creates a new flow registry client

pub async fn create_parameter_provider( &self, body: &Value, ) -> Result<ParameterProviderEntity, NifiError>

Creates a new parameter provider

pub async fn create_reporting_task( &self, body: &Value, ) -> Result<ReportingTaskEntity, NifiError>

Creates a new reporting task

pub async fn delete_flow_analysis_rule_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>

Deletes the Verification Request with the given ID

pub async fn delete_flow_registry_client( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<FlowRegistryClientEntity, NifiError>

Deletes a flow registry client

pub async fn delete_history( &self, end_date: &str, ) -> Result<HistoryDto, NifiError>

Purges history

pub async fn delete_nar( &self, id: &str, disconnected_node_acknowledged: Option<bool>, force: Option<bool>, ) -> Result<NarSummaryDto, NifiError>

Deletes an installed NAR

pub async fn delete_node(&self, id: &str) -> Result<NodeDto, NifiError>

Removes a node from the cluster

pub async fn delete_registry_client_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>

Deletes the Verification Request with the given ID

pub async fn download_nar(&self, id: &str) -> Result<(), NifiError>

Retrieves the content of the NAR with the given id

pub async fn get_cluster(&self) -> Result<ClusterDto, NifiError>

Gets the contents of the cluster

pub async fn get_controller_config( &self, ) -> Result<ControllerConfigurationEntity, NifiError>

Retrieves the configuration for this NiFi Controller

pub async fn get_flow_analysis_rule( &self, id: &str, ) -> Result<FlowAnalysisRuleEntity, NifiError>

Gets a flow analysis rule

pub async fn get_flow_analysis_rule_property_descriptor( &self, id: &str, property_name: &str, sensitive: Option<bool>, ) -> Result<PropertyDescriptorDto, NifiError>

Gets a flow analysis rule property descriptor

pub async fn get_flow_analysis_rule_state( &self, id: &str, ) -> Result<ComponentStateDto, NifiError>

Gets the state for a flow analysis rule

pub async fn get_flow_analysis_rule_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>

Returns the Verification Request with the given ID

pub async fn get_flow_analysis_rules( &self, ) -> Result<FlowAnalysisRulesEntity, NifiError>

Gets all flow analysis rules

pub async fn get_flow_registry_client( &self, id: &str, ) -> Result<FlowRegistryClientEntity, NifiError>

Gets a flow registry client

pub async fn get_flow_registry_clients( &self, ) -> Result<FlowRegistryClientsEntity, NifiError>

Gets the listing of available flow registry clients

pub async fn get_nar_details( &self, id: &str, ) -> Result<NarDetailsEntity, NifiError>

Retrieves the component types available from the installed NARs

pub async fn get_nar_summaries(&self) -> Result<NarSummariesEntity, NifiError>

Retrieves summary information for installed NARs

pub async fn get_nar_summary( &self, id: &str, ) -> Result<NarDetailsEntity, NifiError>

Retrieves the summary information for the NAR with the given identifier

pub async fn get_node(&self, id: &str) -> Result<NodeDto, NifiError>

Gets a node in the cluster

pub async fn get_node_status_history( &self, ) -> Result<ComponentHistoryDto, NifiError>

Gets status history for the node

pub async fn get_property_descriptor( &self, id: &str, property_name: &str, sensitive: Option<bool>, ) -> Result<PropertyDescriptorDto, NifiError>

Gets a flow registry client property descriptor

pub async fn get_registry_client_types( &self, ) -> Result<FlowRegistryClientTypesEntity, NifiError>

Retrieves the types of flow that this NiFi supports

pub async fn get_registry_client_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>

Returns the Verification Request with the given ID

pub async fn import_reporting_task_snapshot( &self, body: &Value, ) -> Result<VersionedReportingTaskImportResponseEntity, NifiError>

Imports a reporting task snapshot

pub async fn remove_flow_analysis_rule( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<FlowAnalysisRuleEntity, NifiError>

Deletes a flow analysis rule

pub async fn submit_flow_analysis_rule_config_verification_request( &self, id: &str, body: &Value, ) -> Result<VerifyConfigRequestDto, NifiError>

Performs verification of the Flow Analysis Rule’s configuration

pub async fn submit_registry_client_config_verification_request( &self, id: &str, body: &Value, ) -> Result<VerifyConfigRequestDto, NifiError>

Performs verification of the Registry Client’s configuration

pub async fn update_controller_config( &self, body: &Value, ) -> Result<ControllerConfigurationEntity, NifiError>

Retrieves the configuration for this NiFi

pub async fn update_flow_analysis_rule( &self, id: &str, body: &Value, ) -> Result<FlowAnalysisRuleEntity, NifiError>

Updates a flow analysis rule

pub async fn update_flow_registry_client( &self, id: &str, body: &Value, ) -> Result<FlowRegistryClientEntity, NifiError>

Updates a flow registry client

pub async fn update_node( &self, id: &str, body: &Value, ) -> Result<NodeDto, NifiError>

Updates a node in the cluster

pub async fn update_run_status( &self, id: &str, body: &Value, ) -> Result<FlowAnalysisRuleEntity, NifiError>

Updates run status of a flow analysis rule

pub async fn upload_nar( &self, filename: Option<&str>, data: Vec<u8>, ) -> Result<NarSummaryDto, NifiError>

Uploads a NAR and requests for it to be installed