pub struct DynamicFlowFileQueuesApi<'a> { /* private fields */ }Expand description
Dynamic dispatch wrapper for the FlowFileQueues API.
Implementations
Sourceimpl<'a> DynamicFlowFileQueuesApi<'a>
impl<'a> DynamicFlowFileQueuesApi<'a>
Sourcepub async fn create_drop_request(
&self,
id: &str,
) -> Result<DropRequestDto, NifiError>
pub async fn create_drop_request( &self, id: &str, ) -> Result<DropRequestDto, NifiError>
Creates a request to drop the contents of the queue in this connection.
Sourcepub async fn create_flow_file_listing(
&self,
id: &str,
) -> Result<ListingRequestDto, NifiError>
pub async fn create_flow_file_listing( &self, id: &str, ) -> Result<ListingRequestDto, NifiError>
Lists the contents of the queue in this connection.
Sourcepub async fn delete_listing_request(
&self,
id: &str,
listing_request_id: &str,
) -> Result<ListingRequestDto, NifiError>
pub async fn delete_listing_request( &self, id: &str, listing_request_id: &str, ) -> Result<ListingRequestDto, NifiError>
Cancels and/or removes a request to list the contents of this connection.
Sourcepub async fn download_flow_file_content(
&self,
id: &str,
flowfile_uuid: &str,
client_id: Option<&str>,
cluster_node_id: Option<&str>,
) -> Result<(), NifiError>
pub async fn download_flow_file_content( &self, id: &str, flowfile_uuid: &str, client_id: Option<&str>, cluster_node_id: Option<&str>, ) -> Result<(), NifiError>
Gets the content for a FlowFile in a Connection.
Sourcepub async fn get_drop_request(
&self,
id: &str,
drop_request_id: &str,
) -> Result<DropRequestDto, NifiError>
pub async fn get_drop_request( &self, id: &str, drop_request_id: &str, ) -> Result<DropRequestDto, NifiError>
Gets the current status of a drop request for the specified connection.
Sourcepub async fn get_flow_file(
&self,
id: &str,
flowfile_uuid: &str,
cluster_node_id: Option<&str>,
) -> Result<FlowFileDto, NifiError>
pub async fn get_flow_file( &self, id: &str, flowfile_uuid: &str, cluster_node_id: Option<&str>, ) -> Result<FlowFileDto, NifiError>
Gets a FlowFile from a Connection.
Sourcepub async fn get_listing_request(
&self,
id: &str,
listing_request_id: &str,
) -> Result<ListingRequestDto, NifiError>
pub async fn get_listing_request( &self, id: &str, listing_request_id: &str, ) -> Result<ListingRequestDto, NifiError>
Gets the current status of a listing request for the specified connection.
Sourcepub async fn remove_drop_request(
&self,
id: &str,
drop_request_id: &str,
) -> Result<DropRequestDto, NifiError>
pub async fn remove_drop_request( &self, id: &str, drop_request_id: &str, ) -> Result<DropRequestDto, NifiError>
Cancels and/or removes a request to drop the contents of this connection.