DynamicProcessGroupsApi

Struct DynamicProcessGroupsApi 

pub struct DynamicProcessGroupsApi<'a> { /* private fields */ }
Dynamic dispatch wrapper for the ProcessGroups API.

Implementations

Source

impl<'a> DynamicProcessGroupsApi<'a>

pub async fn copy( &self, id: &str, body: &Value, ) -> Result<CopyResponseEntity, NifiError>

Generates a copy response for the given copy request

pub async fn copy_snippet( &self, id: &str, body: &Value, ) -> Result<FlowDto, NifiError>

Copies a snippet and discards it.

pub async fn create_connection( &self, id: &str, body: &Value, ) -> Result<ConnectionEntity, NifiError>

Creates a connection

pub async fn create_controller_service_1( &self, id: &str, body: &Value, ) -> Result<ControllerServiceEntity, NifiError>

Creates a new controller service

pub async fn create_empty_all_connections_request( &self, id: &str, ) -> Result<DropRequestDto, NifiError>

Creates a request to drop all flowfiles of all connection queues in this process group.

pub async fn create_funnel( &self, id: &str, body: &Value, ) -> Result<FunnelEntity, NifiError>

Creates a funnel

pub async fn create_input_port( &self, id: &str, body: &Value, ) -> Result<PortEntity, NifiError>

Creates an input port

pub async fn create_label( &self, id: &str, body: &Value, ) -> Result<LabelEntity, NifiError>

Creates a label

pub async fn create_output_port( &self, id: &str, body: &Value, ) -> Result<PortEntity, NifiError>

Creates an output port

pub async fn create_process_group( &self, id: &str, parameter_context_handling_strategy: Option<&str>, body: &Value, ) -> Result<ProcessGroupEntity, NifiError>

Creates a process group

pub async fn create_processor( &self, id: &str, body: &Value, ) -> Result<ProcessorEntity, NifiError>

Creates a new processor

pub async fn create_remote_process_group( &self, id: &str, body: &Value, ) -> Result<RemoteProcessGroupEntity, NifiError>

Creates a new process group

pub async fn delete_replace_process_group_request( &self, id: &str, disconnected_node_acknowledged: Option<bool>, ) -> Result<ProcessGroupReplaceRequestEntity, NifiError>

Deletes the Replace Request with the given ID

pub async fn export_process_group( &self, id: &str, include_referenced_services: Option<bool>, ) -> Result<(), NifiError>

Gets a process group for download

pub async fn get_connections( &self, id: &str, ) -> Result<ConnectionsEntity, NifiError>

Gets all connections

pub async fn get_drop_all_flowfiles_request( &self, id: &str, drop_request_id: &str, ) -> Result<DropRequestDto, NifiError>

Gets the current status of a drop all flowfiles request.

pub async fn get_funnels(&self, id: &str) -> Result<FunnelsEntity, NifiError>

Gets all funnels

pub async fn get_input_ports( &self, id: &str, ) -> Result<InputPortsEntity, NifiError>

Gets all input ports

pub async fn get_labels(&self, id: &str) -> Result<LabelsEntity, NifiError>

Gets all labels

pub async fn get_local_modifications( &self, id: &str, ) -> Result<FlowComparisonEntity, NifiError>

Gets a list of local modifications to the Process Group since it was last synchronized with the Flow Registry

pub async fn get_output_ports( &self, id: &str, ) -> Result<OutputPortsEntity, NifiError>

Gets all output ports

pub async fn get_process_group( &self, id: &str, ) -> Result<ProcessGroupEntity, NifiError>

Gets a process group

pub async fn get_process_groups( &self, id: &str, ) -> Result<ProcessGroupsEntity, NifiError>

Gets all process groups

pub async fn get_processors( &self, id: &str, include_descendant_groups: Option<bool>, ) -> Result<ProcessorsEntity, NifiError>

Gets all processors

pub async fn get_remote_process_groups( &self, id: &str, ) -> Result<RemoteProcessGroupsEntity, NifiError>

Gets all remote process groups

pub async fn get_replace_process_group_request( &self, id: &str, ) -> Result<ProcessGroupReplaceRequestEntity, NifiError>

Returns the Replace Request with the given ID

pub async fn import_process_group( &self, id: &str, body: &Value, ) -> Result<ProcessGroupEntity, NifiError>

Imports a specified process group

pub async fn initiate_replace_process_group( &self, id: &str, body: &Value, ) -> Result<ProcessGroupReplaceRequestEntity, NifiError>

Initiate the Replace Request of a Process Group with the given ID

pub async fn paste( &self, id: &str, body: &Value, ) -> Result<PasteResponseEntity, NifiError>

Pastes into the specified process group

pub async fn remove_drop_request_1( &self, id: &str, drop_request_id: &str, ) -> Result<DropRequestDto, NifiError>

Cancels and/or removes a request to drop all flowfiles.

pub async fn remove_process_group( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<ProcessGroupEntity, NifiError>

Deletes a process group

pub async fn replace_process_group( &self, id: &str, body: &Value, ) -> Result<ProcessGroupImportEntity, NifiError>

Replace Process Group contents with the given ID with the specified Process Group contents

pub async fn update_process_group( &self, id: &str, body: &Value, ) -> Result<ProcessGroupEntity, NifiError>

Updates a process group

pub async fn upload_process_group( &self, id: &str, ) -> Result<ProcessGroupEntity, NifiError>

Uploads a versioned flow definition and creates a process group