pub struct DynamicProcessorsApi<'a> { /* private fields */ }Expand description
Dynamic dispatch wrapper for the Processors API.
Implementations
Sourceimpl<'a> DynamicProcessorsApi<'a>
impl<'a> DynamicProcessorsApi<'a>
Sourcepub async fn analyze_configuration_2(
&self,
id: &str,
body: &Value,
) -> Result<ConfigurationAnalysisDto, NifiError>
pub async fn analyze_configuration_2( &self, id: &str, body: &Value, ) -> Result<ConfigurationAnalysisDto, NifiError>
Performs analysis of the component’s configuration, providing information about which attributes are referenced.
Sourcepub async fn clear_bulletins_5(
&self,
id: &str,
body: &Value,
) -> Result<ClearBulletinsResultEntity, NifiError>
pub async fn clear_bulletins_5( &self, id: &str, body: &Value, ) -> Result<ClearBulletinsResultEntity, NifiError>
Clears bulletins for a processor
Sourcepub async fn clear_state_3(
&self,
id: &str,
body: &Value,
) -> Result<ComponentStateDto, NifiError>
pub async fn clear_state_3( &self, id: &str, body: &Value, ) -> Result<ComponentStateDto, NifiError>
Clears the state for a processor
Sourcepub async fn delete_processor(
&self,
id: &str,
version: Option<&str>,
client_id: Option<&str>,
disconnected_node_acknowledged: Option<bool>,
) -> Result<ProcessorEntity, NifiError>
pub async fn delete_processor( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<ProcessorEntity, NifiError>
Deletes a processor
Sourcepub async fn delete_verification_request_2(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn delete_verification_request_2( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Deletes the Verification Request with the given ID
Sourcepub async fn get_processor(
&self,
id: &str,
) -> Result<ProcessorEntity, NifiError>
pub async fn get_processor( &self, id: &str, ) -> Result<ProcessorEntity, NifiError>
Gets a processor
Sourcepub async fn get_processor_diagnostics(
&self,
id: &str,
) -> Result<ProcessorEntity, NifiError>
pub async fn get_processor_diagnostics( &self, id: &str, ) -> Result<ProcessorEntity, NifiError>
Gets diagnostics information about a processor
Sourcepub async fn get_processor_run_status_details(
&self,
body: &Value,
) -> Result<ProcessorsRunStatusDetailsEntity, NifiError>
pub async fn get_processor_run_status_details( &self, body: &Value, ) -> Result<ProcessorsRunStatusDetailsEntity, NifiError>
Submits a query to retrieve the run status details of all processors that are in the given list of Processor IDs
Sourcepub async fn get_property_descriptor_3(
&self,
id: &str,
client_id: Option<&str>,
property_name: &str,
sensitive: Option<bool>,
) -> Result<PropertyDescriptorDto, NifiError>
pub async fn get_property_descriptor_3( &self, id: &str, client_id: Option<&str>, property_name: &str, sensitive: Option<bool>, ) -> Result<PropertyDescriptorDto, NifiError>
Gets the descriptor for a processor property
Sourcepub async fn get_state_2(
&self,
id: &str,
) -> Result<ComponentStateDto, NifiError>
pub async fn get_state_2( &self, id: &str, ) -> Result<ComponentStateDto, NifiError>
Gets the state for a processor
Sourcepub async fn get_verification_request_2(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn get_verification_request_2( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Returns the Verification Request with the given ID
Sourcepub async fn submit_processor_verification_request(
&self,
id: &str,
body: &Value,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn submit_processor_verification_request( &self, id: &str, body: &Value, ) -> Result<VerifyConfigRequestDto, NifiError>
Performs verification of the Processor’s configuration
Sourcepub async fn terminate_processor(
&self,
id: &str,
) -> Result<ProcessorEntity, NifiError>
pub async fn terminate_processor( &self, id: &str, ) -> Result<ProcessorEntity, NifiError>
Terminates a processor, essentially “deleting” its threads and any active tasks
Sourcepub async fn update_processor(
&self,
id: &str,
body: &Value,
) -> Result<ProcessorEntity, NifiError>
pub async fn update_processor( &self, id: &str, body: &Value, ) -> Result<ProcessorEntity, NifiError>
Updates a processor
Sourcepub async fn update_run_status_4(
&self,
id: &str,
body: &Value,
) -> Result<ProcessorEntity, NifiError>
pub async fn update_run_status_4( &self, id: &str, body: &Value, ) -> Result<ProcessorEntity, NifiError>
Updates run status of a processor