pub struct DynamicSnippetsApi<'a> { /* private fields */ }Expand description
Dynamic dispatch wrapper for the Snippets API.
Implementations
Sourceimpl<'a> DynamicSnippetsApi<'a>
impl<'a> DynamicSnippetsApi<'a>
Sourcepub async fn create_snippet(
&self,
body: &Value,
) -> Result<SnippetEntity, NifiError>
pub async fn create_snippet( &self, body: &Value, ) -> Result<SnippetEntity, NifiError>
Creates a snippet. The snippet will be automatically discarded if not used in a subsequent request after 1 minute.
Sourcepub async fn delete_snippet(
&self,
id: &str,
disconnected_node_acknowledged: Option<bool>,
) -> Result<SnippetEntity, NifiError>
pub async fn delete_snippet( &self, id: &str, disconnected_node_acknowledged: Option<bool>, ) -> Result<SnippetEntity, NifiError>
Deletes the components in a snippet and discards the snippet
Sourcepub async fn update_snippet(
&self,
id: &str,
body: &Value,
) -> Result<SnippetEntity, NifiError>
pub async fn update_snippet( &self, id: &str, body: &Value, ) -> Result<SnippetEntity, NifiError>
Move’s the components in this Snippet into a new Process Group and discards the snippet