DynamicVersionsApi

Struct DynamicVersionsApi 

pub struct DynamicVersionsApi<'a> { /* private fields */ }
Dynamic dispatch wrapper for the Versions API.

Implementations

Source

impl<'a> DynamicVersionsApi<'a>

pub async fn create_version_control_request( &self, body: &Value, ) -> Result<(), NifiError>

Create a version control request

pub async fn delete_revert_request( &self, id: &str, disconnected_node_acknowledged: Option<bool>, ) -> Result<VersionedFlowUpdateRequestEntity, NifiError>

Deletes the Revert Request with the given ID

pub async fn delete_update_request_1( &self, id: &str, disconnected_node_acknowledged: Option<bool>, ) -> Result<VersionedFlowUpdateRequestEntity, NifiError>

Deletes the Update Request with the given ID

pub async fn delete_version_control_request( &self, id: &str, disconnected_node_acknowledged: Option<bool>, ) -> Result<(), NifiError>

Deletes the version control request with the given ID

pub async fn export_flow_version(&self, id: &str) -> Result<(), NifiError>

Gets the latest version of a Process Group for download

pub async fn get_revert_request( &self, id: &str, ) -> Result<VersionedFlowUpdateRequestEntity, NifiError>

Returns the Revert Request with the given ID

pub async fn get_update_request( &self, id: &str, ) -> Result<VersionedFlowUpdateRequestEntity, NifiError>

Returns the Update Request with the given ID

pub async fn get_version_information( &self, id: &str, ) -> Result<VersionControlInformationEntity, NifiError>

Gets the Version Control information for a process group

pub async fn initiate_revert_flow_version( &self, id: &str, body: &Value, ) -> Result<VersionedFlowUpdateRequestEntity, NifiError>

Initiate the Revert Request of a Process Group with the given ID

pub async fn initiate_version_control_update( &self, id: &str, body: &Value, ) -> Result<VersionedFlowUpdateRequestEntity, NifiError>

Initiate the Update Request of a Process Group with the given ID

pub async fn save_to_flow_registry( &self, id: &str, body: &Value, ) -> Result<VersionControlInformationEntity, NifiError>

Save the Process Group with the given ID

pub async fn stop_version_control( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<VersionControlInformationEntity, NifiError>

Stops version controlling the Process Group with the given ID

pub async fn update_flow_version( &self, id: &str, body: &Value, ) -> Result<VersionControlInformationEntity, NifiError>

Update the version of a Process Group with the given ID

pub async fn update_version_control_request( &self, id: &str, body: &Value, ) -> Result<VersionControlInformationEntity, NifiError>

Updates the request with the given ID