pub struct ControllerConfigApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ControllerConfigApi<'a>
impl<'a> ControllerConfigApi<'a>
Sourcepub async fn analyze_flow_analysis_rule_configuration(
&self,
body: &ConfigurationAnalysisEntity,
) -> Result<ConfigurationAnalysisDto, NifiError>
pub async fn analyze_flow_analysis_rule_configuration( &self, body: &ConfigurationAnalysisEntity, ) -> Result<ConfigurationAnalysisDto, NifiError>
Performs analysis of the component’s configuration, providing information about which attributes are referenced.
Calls POST /nifi-api/controller/flow-analysis-rules/{id}/config/analysis.
Parameters
body: The configuration analysis request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow-analysis-rules/{uuid}.
Sourcepub async fn submit_flow_analysis_rule_config_verification_request(
&self,
body: &VerifyConfigRequestEntity,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn submit_flow_analysis_rule_config_verification_request( &self, body: &VerifyConfigRequestEntity, ) -> Result<VerifyConfigRequestDto, NifiError>
Performs verification of the Flow Analysis Rule’s configuration
This will initiate the process of verifying a given Flow Analysis Rule configuration. This may be a long-running task. As a result, this endpoint will immediately return a FlowAnalysisRuleConfigVerificationRequestEntity, and the process of performing the verification will occur asynchronously in the background. The client may then periodically poll the status of the request by issuing a GET request to /flow-analysis-rules/{taskId}/verification-requests/{requestId}. Once the request is completed, the client is expected to issue a DELETE request to /flow-analysis-rules/{serviceId}/verification-requests/{requestId}.
Calls POST /nifi-api/controller/flow-analysis-rules/{id}/config/verification-requests.
Parameters
body: The flow analysis rules configuration verification request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow-analysis-rules/{uuid}.
Sourcepub async fn delete_flow_analysis_rule_verification_request(
&self,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn delete_flow_analysis_rule_verification_request( &self, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Deletes the Verification Request with the given ID
Deletes the Verification Request with the given ID. After a request is created, it is expected that the client will properly clean up the request by DELETE’ing it, once the Verification process has completed. If the request is deleted before the request completes, then the Verification request will finish the step that it is currently performing and then will cancel any subsequent steps.
Calls DELETE /nifi-api/controller/flow-analysis-rules/{id}/config/verification-requests/{requestId}.
Parameters
request_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can remove it.
Sourcepub async fn get_flow_analysis_rule_verification_request(
&self,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn get_flow_analysis_rule_verification_request( &self, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Returns the Verification Request with the given ID
Returns the Verification Request with the given ID. Once an Verification Request has been created, that request can subsequently be retrieved via this endpoint, and the request that is fetched will contain the updated state, such as percent complete, the current state of the request, and any failures.
Calls GET /nifi-api/controller/flow-analysis-rules/{id}/config/verification-requests/{requestId}.
Parameters
request_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can get it.