pub struct ControllerStateApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ControllerStateApi<'a>
impl<'a> ControllerStateApi<'a>
Sourcepub async fn get_flow_analysis_rule_state(
&self,
) -> Result<ComponentStateDto, NifiError>
pub async fn get_flow_analysis_rule_state( &self, ) -> Result<ComponentStateDto, NifiError>
Gets the state for a flow analysis rule
Calls GET /nifi-api/controller/flow-analysis-rules/{id}/state.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /flow-analysis-rules/{uuid}.
Sourcepub async fn clear_state(
&self,
body: &ComponentStateEntity,
) -> Result<ComponentStateDto, NifiError>
pub async fn clear_state( &self, body: &ComponentStateEntity, ) -> Result<ComponentStateDto, NifiError>
Clears the state for a flow analysis rule
Calls POST /nifi-api/controller/flow-analysis-rules/{id}/state/clear-requests.
Parameters
body: Optional component state to perform a selective key removal. If omitted, clears all state.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /flow-analysis-rules/{uuid}.