pub struct ProcessGroupsLabelsApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsLabelsApi<'a>
impl<'a> ProcessGroupsLabelsApi<'a>
Sourcepub async fn get_labels(&self) -> Result<LabelsEntity, NifiError>
pub async fn get_labels(&self) -> Result<LabelsEntity, NifiError>
Gets all labels
Calls GET /nifi-api/process-groups/{id}/labels.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /process-groups/{uuid}.
Sourcepub async fn create_label(
&self,
body: &LabelEntity,
) -> Result<LabelEntity, NifiError>
pub async fn create_label( &self, body: &LabelEntity, ) -> Result<LabelEntity, NifiError>
Creates a label
Calls POST /nifi-api/process-groups/{id}/labels.
Parameters
body: The label configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /process-groups/{uuid}.