pub struct ProcessGroupsPasteApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsPasteApi<'a>
impl<'a> ProcessGroupsPasteApi<'a>
Sourcepub async fn paste(
&self,
body: &PasteRequestEntity,
) -> Result<PasteResponseEntity, NifiError>
pub async fn paste( &self, body: &PasteRequestEntity, ) -> Result<PasteResponseEntity, NifiError>
Pastes into the specified process group
Calls PUT /nifi-api/process-groups/{id}/paste.
Parameters
body: The request including the components to be pasted into the specified Process Group.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /process-groups/{uuid}.