pub struct ProcessGroupsProcessorsApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsProcessorsApi<'a>
impl<'a> ProcessGroupsProcessorsApi<'a>
Sourcepub async fn get_processors(
&self,
include_descendant_groups: Option<bool>,
) -> Result<ProcessorsEntity, NifiError>
pub async fn get_processors( &self, include_descendant_groups: Option<bool>, ) -> Result<ProcessorsEntity, NifiError>
Gets all processors
Calls GET /nifi-api/process-groups/{id}/processors.
Parameters
include_descendant_groups: Whether or not to include processors from descendant process groups
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /process-groups/{uuid}.
Sourcepub async fn create_processor(
&self,
body: &ProcessorEntity,
) -> Result<ProcessorEntity, NifiError>
pub async fn create_processor( &self, body: &ProcessorEntity, ) -> Result<ProcessorEntity, NifiError>
Creates a new processor
Calls POST /nifi-api/process-groups/{id}/processors.
Parameters
body: The processor configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /process-groups/{uuid}Read - any referenced Controller Services - /controller-services/{uuid}Write - if the Processor is restricted - /restricted-components