pub struct ProcessorsThreadsApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessorsThreadsApi<'a>
impl<'a> ProcessorsThreadsApi<'a>
Sourcepub async fn terminate_processor(&self) -> Result<ProcessorEntity, NifiError>
pub async fn terminate_processor(&self) -> Result<ProcessorEntity, NifiError>
Terminates a processor, essentially “deleting” its threads and any active tasks
Calls DELETE /nifi-api/processors/{id}/threads.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /processors/{uuid} or /operation/processors/{uuid}.