pub struct ControllerRunStatusApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ControllerRunStatusApi<'a>
impl<'a> ControllerRunStatusApi<'a>
Sourcepub async fn update_run_status(
&self,
body: &FlowAnalysisRuleRunStatusEntity,
) -> Result<FlowAnalysisRuleEntity, NifiError>
pub async fn update_run_status( &self, body: &FlowAnalysisRuleRunStatusEntity, ) -> Result<FlowAnalysisRuleEntity, NifiError>
Updates run status of a flow analysis rule
Calls PUT /nifi-api/controller/flow-analysis-rules/{id}/run-status.
Parameters
body: The flow analysis rule run status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /flow-analysis-rules/{uuid} or or /operation/flow-analysis-rules/{uuid}.