pub struct ControllerServicesReferencesApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ControllerServicesReferencesApi<'a>
impl<'a> ControllerServicesReferencesApi<'a>
Sourcepub async fn get_controller_service_references(
&self,
) -> Result<ControllerServiceReferencingComponentsEntity, NifiError>
pub async fn get_controller_service_references( &self, ) -> Result<ControllerServiceReferencingComponentsEntity, NifiError>
Gets a controller service
Calls GET /nifi-api/controller-services/{id}/references.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller-services/{uuid}.
Sourcepub async fn update_controller_service_references(
&self,
body: &UpdateControllerServiceReferenceRequestEntity,
) -> Result<ControllerServiceReferencingComponentsEntity, NifiError>
pub async fn update_controller_service_references( &self, body: &UpdateControllerServiceReferenceRequestEntity, ) -> Result<ControllerServiceReferencingComponentsEntity, NifiError>
Updates a controller services references
Calls PUT /nifi-api/controller-services/{id}/references.
Parameters
body: The controller service request update request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /{component-type}/{uuid} or /operate/{component-type}/{uuid} - For each referencing component specified.