pub struct ControllerServicesRunStatusApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ControllerServicesRunStatusApi<'a>
impl<'a> ControllerServicesRunStatusApi<'a>
Sourcepub async fn update_run_status_1(
&self,
body: &ControllerServiceRunStatusEntity,
) -> Result<ControllerServiceEntity, NifiError>
pub async fn update_run_status_1( &self, body: &ControllerServiceRunStatusEntity, ) -> Result<ControllerServiceEntity, NifiError>
Updates run status of a controller service
Calls PUT /nifi-api/controller-services/{id}/run-status.
Parameters
body: The controller service run status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller-services/{uuid} or /operation/controller-services/{uuid}.