pub struct ProcessGroupsConnectionsApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsConnectionsApi<'a>
impl<'a> ProcessGroupsConnectionsApi<'a>
Sourcepub async fn get_connections(&self) -> Result<ConnectionsEntity, NifiError>
pub async fn get_connections(&self) -> Result<ConnectionsEntity, NifiError>
Gets all connections
Calls GET /nifi-api/process-groups/{id}/connections.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /process-groups/{uuid}.
Sourcepub async fn create_connection(
&self,
body: &ConnectionEntity,
) -> Result<ConnectionEntity, NifiError>
pub async fn create_connection( &self, body: &ConnectionEntity, ) -> Result<ConnectionEntity, NifiError>
Creates a connection
Calls POST /nifi-api/process-groups/{id}/connections.
Parameters
body: The connection configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /process-groups/{uuid}Write Source - /{component-type}/{uuid}Write Destination - /{component-type}/{uuid}