pub struct ProcessGroupsDownloadApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsDownloadApi<'a>
impl<'a> ProcessGroupsDownloadApi<'a>
Sourcepub async fn export_process_group(
&self,
include_referenced_services: Option<bool>,
) -> Result<(), NifiError>
pub async fn export_process_group( &self, include_referenced_services: Option<bool>, ) -> Result<(), NifiError>
Gets a process group for download
Calls GET /nifi-api/process-groups/{id}/download.
Parameters
include_referenced_services: If referenced services from outside the target group should be included
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /process-groups/{uuid}.