pub struct ProcessGroupsEmptyAllConnectionsRequestsApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsEmptyAllConnectionsRequestsApi<'a>
impl<'a> ProcessGroupsEmptyAllConnectionsRequestsApi<'a>
Sourcepub async fn create_empty_all_connections_request(
&self,
) -> Result<DropRequestDto, NifiError>
pub async fn create_empty_all_connections_request( &self, ) -> Result<DropRequestDto, NifiError>
Creates a request to drop all flowfiles of all connection queues in this process group.
Calls POST /nifi-api/process-groups/{id}/empty-all-connections-requests.
Returns
202: The request has been accepted. An HTTP response header will contain the URI where the status can be polled.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Read - /process-groups/{uuid} - For this and all encapsulated process groupsWrite Source Data - /data/{component-type}/{uuid} - For all encapsulated connections
Sourcepub async fn remove_drop_request_1(
&self,
drop_request_id: &str,
) -> Result<DropRequestDto, NifiError>
pub async fn remove_drop_request_1( &self, drop_request_id: &str, ) -> Result<DropRequestDto, NifiError>
Cancels and/or removes a request to drop all flowfiles.
Calls DELETE /nifi-api/process-groups/{id}/empty-all-connections-requests/{drop-request-id}.
Parameters
drop_request_id: The drop request id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Read - /process-groups/{uuid} - For this and all encapsulated process groupsWrite Source Data - /data/{component-type}/{uuid} - For all encapsulated connections
Sourcepub async fn get_drop_all_flowfiles_request(
&self,
drop_request_id: &str,
) -> Result<DropRequestDto, NifiError>
pub async fn get_drop_all_flowfiles_request( &self, drop_request_id: &str, ) -> Result<DropRequestDto, NifiError>
Gets the current status of a drop all flowfiles request.
Calls GET /nifi-api/process-groups/{id}/empty-all-connections-requests/{drop-request-id}.
Parameters
drop_request_id: The drop request id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Read - /process-groups/{uuid} - For this and all encapsulated process groupsWrite Source Data - /data/{component-type}/{uuid} - For all encapsulated connections