pub struct ProcessGroupsProcessGroupsApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsProcessGroupsApi<'a>
impl<'a> ProcessGroupsProcessGroupsApi<'a>
Sourcepub async fn get_process_groups(&self) -> Result<ProcessGroupsEntity, NifiError>
pub async fn get_process_groups(&self) -> Result<ProcessGroupsEntity, NifiError>
Gets all process groups
Calls GET /nifi-api/process-groups/{id}/process-groups.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /process-groups/{uuid}.
Sourcepub async fn create_process_group(
&self,
parameter_context_handling_strategy: Option<ParameterContextHandlingStrategy>,
body: &ProcessGroupEntity,
) -> Result<ProcessGroupEntity, NifiError>
pub async fn create_process_group( &self, parameter_context_handling_strategy: Option<ParameterContextHandlingStrategy>, body: &ProcessGroupEntity, ) -> Result<ProcessGroupEntity, NifiError>
Creates a process group
Calls POST /nifi-api/process-groups/{id}/process-groups.
Parameters
parameter_context_handling_strategy: Handling Strategy controls whether to keep or replace Parameter Contextsbody: The process group configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /process-groups/{uuid}.
Sourcepub async fn import_process_group(
&self,
body: &ProcessGroupUploadEntity,
) -> Result<ProcessGroupEntity, NifiError>
pub async fn import_process_group( &self, body: &ProcessGroupUploadEntity, ) -> Result<ProcessGroupEntity, NifiError>
Imports a specified process group
Calls POST /nifi-api/process-groups/{id}/process-groups/import.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /process-groups/{uuid}.
Sourcepub async fn upload_process_group(
&self,
) -> Result<ProcessGroupEntity, NifiError>
pub async fn upload_process_group( &self, ) -> Result<ProcessGroupEntity, NifiError>
Uploads a versioned flow definition and creates a process group
Calls POST /nifi-api/process-groups/{id}/process-groups/upload.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /process-groups/{uuid}.