pub struct ProcessGroupsReplaceRequestsApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsReplaceRequestsApi<'a>
impl<'a> ProcessGroupsReplaceRequestsApi<'a>
Sourcepub async fn initiate_replace_process_group(
&self,
body: &ProcessGroupImportEntity,
) -> Result<ProcessGroupReplaceRequestEntity, NifiError>
pub async fn initiate_replace_process_group( &self, body: &ProcessGroupImportEntity, ) -> Result<ProcessGroupReplaceRequestEntity, NifiError>
Initiate the Replace Request of a Process Group with the given ID
This will initiate the action of replacing a process group with the given process group. This can be a lengthy process, as it will stop any Processors and disable any Controller Services necessary to perform the action and then restart them. As a result, the endpoint will immediately return a ProcessGroupReplaceRequestEntity, and the process of replacing the flow will occur asynchronously in the background. The client may then periodically poll the status of the request by issuing a GET request to /process-groups/replace-requests/{requestId}. Once the request is completed, the client is expected to issue a DELETE request to /process-groups/replace-requests/{requestId}. Note: This endpoint is subject to change as NiFi and it’s REST API evolve.
Calls POST /nifi-api/process-groups/{id}/replace-requests.
Parameters
body: The process group replace request entity
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Read - /process-groups/{uuid}Write - /process-groups/{uuid}Read - /{component-type}/{uuid} - For all encapsulated componentsWrite - /{component-type}/{uuid} - For all encapsulated componentsWrite - if the snapshot contains any restricted components - /restricted-componentsRead - /parameter-contexts/{uuid} - For any Parameter Context that is referenced by a Property that is changed, added, or removed