ProcessorsConfigApi

Struct ProcessorsConfigApi 

pub struct ProcessorsConfigApi<'a> { /* private fields */ }

Implementations

Source

impl<'a> ProcessorsConfigApi<'a>

pub async fn analyze_configuration_2( &self, body: &ConfigurationAnalysisEntity, ) -> Result<ConfigurationAnalysisDto, NifiError>

Performs analysis of the component’s configuration, providing information about which attributes are referenced.

Calls POST /nifi-api/processors/{id}/config/analysis.

Parameters
  • body: The processor configuration analysis request.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /processors/{uuid}.

pub async fn submit_processor_verification_request( &self, body: &VerifyConfigRequestEntity, ) -> Result<VerifyConfigRequestDto, NifiError>

Performs verification of the Processor’s configuration

This will initiate the process of verifying a given Processor configuration. This may be a long-running task. As a result, this endpoint will immediately return a ProcessorConfigVerificationRequestEntity, and the process of performing the verification will occur asynchronously in the background. The client may then periodically poll the status of the request by issuing a GET request to /processors/{processorId}/verification-requests/{requestId}. Once the request is completed, the client is expected to issue a DELETE request to /processors/{processorId}/verification-requests/{requestId}.

Calls POST /nifi-api/processors/{id}/config/verification-requests.

Parameters
  • body: The processor configuration verification request.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /processors/{uuid}.

pub async fn delete_verification_request_2( &self, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>

Deletes the Verification Request with the given ID

Deletes the Verification Request with the given ID. After a request is created, it is expected that the client will properly clean up the request by DELETE’ing it, once the Verification process has completed. If the request is deleted before the request completes, then the Verification request will finish the step that it is currently performing and then will cancel any subsequent steps.

Calls DELETE /nifi-api/processors/{id}/config/verification-requests/{requestId}.

Parameters
  • request_id: The ID of the Verification Request
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Only the user that submitted the request can remove it.

pub async fn get_verification_request_2( &self, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>

Returns the Verification Request with the given ID

Returns the Verification Request with the given ID. Once an Verification Request has been created, that request can subsequently be retrieved via this endpoint, and the request that is fetched will contain the updated state, such as percent complete, the current state of the request, and any failures.

Calls GET /nifi-api/processors/{id}/config/verification-requests/{requestId}.

Parameters
  • request_id: The ID of the Verification Request
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Only the user that submitted the request can get it.