pub struct ControllerContentApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ControllerContentApi<'a>
impl<'a> ControllerContentApi<'a>
Sourcepub async fn download_nar(&self) -> Result<(), NifiError>
pub async fn download_nar(&self) -> Result<(), NifiError>
Retrieves the content of the NAR with the given id
Calls GET /nifi-api/controller/nar-manager/nars/{id}/content.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.