pub struct ControllerDescriptorsApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ControllerDescriptorsApi<'a>
impl<'a> ControllerDescriptorsApi<'a>
Sourcepub async fn get_flow_analysis_rule_property_descriptor(
&self,
property_name: &str,
sensitive: Option<bool>,
) -> Result<PropertyDescriptorDto, NifiError>
pub async fn get_flow_analysis_rule_property_descriptor( &self, property_name: &str, sensitive: Option<bool>, ) -> Result<PropertyDescriptorDto, NifiError>
Gets a flow analysis rule property descriptor
Calls GET /nifi-api/controller/flow-analysis-rules/{id}/descriptors.
Parameters
property_name: The property name.sensitive: Property Descriptor requested sensitive status
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow-analysis-rules/{uuid}.
Sourcepub async fn get_property_descriptor(
&self,
property_name: &str,
sensitive: Option<bool>,
) -> Result<PropertyDescriptorDto, NifiError>
pub async fn get_property_descriptor( &self, property_name: &str, sensitive: Option<bool>, ) -> Result<PropertyDescriptorDto, NifiError>
Gets a flow registry client property descriptor
Calls GET /nifi-api/controller/registry-clients/{id}/descriptors.
Parameters
property_name: The property name.sensitive: Property Descriptor requested sensitive status
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller/registry-clients/{id}.