ProcessGroupsApi

Struct ProcessGroupsApi 

pub struct ProcessGroupsApi<'a> { /* private fields */ }

Implementations

Source

impl<'a> ProcessGroupsApi<'a>

pub async fn delete_replace_process_group_request( &self, id: &str, disconnected_node_acknowledged: Option<bool>, ) -> Result<ProcessGroupReplaceRequestEntity, NifiError>

Deletes the Replace Request with the given ID

Deletes the Replace Request with the given ID. After a request is created via a POST to /process-groups/{id}/replace-requests, it is expected that the client will properly clean up the request by DELETE’ing it, once the Replace process has completed. If the request is deleted before the request completes, then the Replace request will finish the step that it is currently performing and then will cancel any subsequent steps. Note: This endpoint is subject to change as NiFi and it’s REST API evolve.

Calls DELETE /nifi-api/process-groups/replace-requests/{id}.

Parameters
  • id: The ID of the Update Request
  • disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Only the user that submitted the request can remove it.

pub async fn get_replace_process_group_request( &self, id: &str, ) -> Result<ProcessGroupReplaceRequestEntity, NifiError>

Returns the Replace Request with the given ID

Returns the Replace Request with the given ID. Once a Replace Request has been created by performing a POST to /process-groups/{id}/replace-requests, that request can subsequently be retrieved via this endpoint, and the request that is fetched will contain the updated state, such as percent complete, the current state of the request, and any failures. Note: This endpoint is subject to change as NiFi and it’s REST API evolve.

Calls GET /nifi-api/process-groups/replace-requests/{id}.

Parameters
  • id: The ID of the Replace Request
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Only the user that submitted the request can get it.

pub async fn remove_process_group( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<ProcessGroupEntity, NifiError>

Deletes a process group

Calls DELETE /nifi-api/process-groups/{id}.

Parameters
  • id: The process group id.
  • version: The revision is used to verify the client is working with the latest version of the flow.
  • client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.
  • disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Write - /process-groups/{uuid}
  • Write - Parent Process Group - /process-groups/{uuid}
  • Read - any referenced Controller Services by any encapsulated components - /controller-services/{uuid}
  • Write - /{component-type}/{uuid} - For all encapsulated components
pub async fn get_process_group( &self, id: &str, ) -> Result<ProcessGroupEntity, NifiError>

Gets a process group

Calls GET /nifi-api/process-groups/{id}.

Parameters
  • id: The process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /process-groups/{uuid}.

pub async fn update_process_group( &self, id: &str, body: &ProcessGroupEntity, ) -> Result<ProcessGroupEntity, NifiError>

Updates a process group

Calls PUT /nifi-api/process-groups/{id}.

Parameters
  • id: The process group id.
  • body: The process group configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /process-groups/{uuid}.

pub fn connections<'b>(&'b self, id: &'b str) -> ProcessGroupsConnectionsApi<'b>

Scope operations to the connections sub-resource of a specific process group.

  • id: The process group id.
pub fn controller_services<'b>( &'b self, id: &'b str, ) -> ProcessGroupsControllerServicesApi<'b>

Scope operations to the controller_services sub-resource of a specific process group.

  • id: The process group id.
pub fn copy<'b>(&'b self, id: &'b str) -> ProcessGroupsCopyApi<'b>

Scope operations to the copy sub-resource of a specific process group.

  • id: The process group id.
pub fn download<'b>(&'b self, id: &'b str) -> ProcessGroupsDownloadApi<'b>

Scope operations to the download sub-resource of a specific process group.

  • id: The process group id.
pub fn empty_all_connections_requests<'b>( &'b self, id: &'b str, ) -> ProcessGroupsEmptyAllConnectionsRequestsApi<'b>

Scope operations to the empty_all_connections_requests sub-resource of a specific process group.

  • id: The process group id.
pub fn flow_contents<'b>( &'b self, id: &'b str, ) -> ProcessGroupsFlowContentsApi<'b>

Scope operations to the flow_contents sub-resource of a specific process group.

  • id: The process group id.
pub fn funnels<'b>(&'b self, id: &'b str) -> ProcessGroupsFunnelsApi<'b>

Scope operations to the funnels sub-resource of a specific process group.

  • id: The process group id.
pub fn input_ports<'b>(&'b self, id: &'b str) -> ProcessGroupsInputPortsApi<'b>

Scope operations to the input_ports sub-resource of a specific process group.

  • id: The process group id.
pub fn labels<'b>(&'b self, id: &'b str) -> ProcessGroupsLabelsApi<'b>

Scope operations to the labels sub-resource of a specific process group.

  • id: The process group id.
pub fn local_modifications<'b>( &'b self, id: &'b str, ) -> ProcessGroupsLocalModificationsApi<'b>

Scope operations to the local_modifications sub-resource of a specific process group.

  • id: The process group id.
pub fn output_ports<'b>( &'b self, id: &'b str, ) -> ProcessGroupsOutputPortsApi<'b>

Scope operations to the output_ports sub-resource of a specific process group.

  • id: The process group id.
pub fn paste<'b>(&'b self, id: &'b str) -> ProcessGroupsPasteApi<'b>

Scope operations to the paste sub-resource of a specific process group.

  • id: The process group id.
pub fn process_groups<'b>( &'b self, id: &'b str, ) -> ProcessGroupsProcessGroupsApi<'b>

Scope operations to the process_groups sub-resource of a specific process group.

  • id: The process group id.
pub fn processors<'b>(&'b self, id: &'b str) -> ProcessGroupsProcessorsApi<'b>

Scope operations to the processors sub-resource of a specific process group.

  • id: The process group id.
pub fn remote_process_groups<'b>( &'b self, id: &'b str, ) -> ProcessGroupsRemoteProcessGroupsApi<'b>

Scope operations to the remote_process_groups sub-resource of a specific process group.

  • id: The process group id.
pub fn replace_requests<'b>( &'b self, id: &'b str, ) -> ProcessGroupsReplaceRequestsApi<'b>

Scope operations to the replace_requests sub-resource of a specific process group.

  • id: The process group id.
pub fn snippet_instance<'b>( &'b self, id: &'b str, ) -> ProcessGroupsSnippetInstanceApi<'b>

Scope operations to the snippet_instance sub-resource of a specific process group.

  • id: The process group id.