pub struct ProcessGroupsControllerServicesApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsControllerServicesApi<'a>
impl<'a> ProcessGroupsControllerServicesApi<'a>
Sourcepub async fn create_controller_service_1(
&self,
body: &ControllerServiceEntity,
) -> Result<ControllerServiceEntity, NifiError>
pub async fn create_controller_service_1( &self, body: &ControllerServiceEntity, ) -> Result<ControllerServiceEntity, NifiError>
Creates a new controller service
Calls POST /nifi-api/process-groups/{id}/controller-services.
Parameters
body: The controller service configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /process-groups/{uuid}Read - any referenced Controller Services - /controller-services/{uuid}Write - if the Controller Service is restricted - /restricted-components