pub struct ProcessGroupsCopyApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsCopyApi<'a>
impl<'a> ProcessGroupsCopyApi<'a>
Sourcepub async fn copy(
&self,
body: &CopyRequestEntity,
) -> Result<CopyResponseEntity, NifiError>
pub async fn copy( &self, body: &CopyRequestEntity, ) -> Result<CopyResponseEntity, NifiError>
Generates a copy response for the given copy request
Calls POST /nifi-api/process-groups/{id}/copy.
Parameters
body: The request including the components to be copied from the specified Process Group.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /{component-type}/{uuid} - For all encapsulated components.