pub struct ProcessGroupsFunnelsApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsFunnelsApi<'a>
impl<'a> ProcessGroupsFunnelsApi<'a>
Sourcepub async fn get_funnels(&self) -> Result<FunnelsEntity, NifiError>
pub async fn get_funnels(&self) -> Result<FunnelsEntity, NifiError>
Gets all funnels
Calls GET /nifi-api/process-groups/{id}/funnels.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /process-groups/{uuid}.
Sourcepub async fn create_funnel(
&self,
body: &FunnelEntity,
) -> Result<FunnelEntity, NifiError>
pub async fn create_funnel( &self, body: &FunnelEntity, ) -> Result<FunnelEntity, NifiError>
Creates a funnel
Calls POST /nifi-api/process-groups/{id}/funnels.
Parameters
body: The funnel configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /process-groups/{uuid}.