pub struct ProcessGroupsSnippetInstanceApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsSnippetInstanceApi<'a>
impl<'a> ProcessGroupsSnippetInstanceApi<'a>
Sourcepub async fn copy_snippet(
&self,
body: &CopySnippetRequestEntity,
) -> Result<FlowDto, NifiError>
pub async fn copy_snippet( &self, body: &CopySnippetRequestEntity, ) -> Result<FlowDto, NifiError>
Copies a snippet and discards it.
Calls POST /nifi-api/process-groups/{id}/snippet-instance.
Parameters
body: The copy snippet request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /process-groups/{uuid}Read - /{component-type}/{uuid} - For each component in the snippet and their descendant componentsWrite - if the snippet contains any restricted Processors - /restricted-components