Labels

Struct Labels 

pub struct Labels<'a> { /* private fields */ }

Implementations

Source

impl<'a> Labels<'a>

pub async fn remove_label( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<LabelEntity, NifiError>

Deletes a label

Calls DELETE /nifi-api/labels/{id}.

Parameters
  • id: The label id.
  • version: The revision is used to verify the client is working with the latest version of the flow.
  • client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.
  • disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Write - /labels/{uuid}
  • Write - Parent Process Group - /process-groups/{uuid}
pub async fn get_label(&self, id: &str) -> Result<LabelEntity, NifiError>

Gets a label

Calls GET /nifi-api/labels/{id}.

Parameters
  • id: The label id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /labels/{uuid}.

pub async fn update_label( &self, id: &str, body: &LabelEntity, ) -> Result<LabelEntity, NifiError>

Updates a label

Calls PUT /nifi-api/labels/{id}.

Parameters
  • id: The label id.
  • body: The label configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /labels/{uuid}.