RemoteProcessGroups

Struct RemoteProcessGroups 

pub struct RemoteProcessGroups<'a> { /* private fields */ }

Implementations

Source

impl<'a> RemoteProcessGroups<'a>

pub async fn remove_remote_process_group( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<RemoteProcessGroupEntity, NifiError>

Deletes a remote process group

Calls DELETE /nifi-api/remote-process-groups/{id}.

Parameters
  • id: The remote process group id.
  • version: The revision is used to verify the client is working with the latest version of the flow.
  • client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.
  • disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
  • Write - /remote-process-groups/{uuid}
  • Write - Parent Process Group - /process-groups/{uuid}
pub async fn get_remote_process_group( &self, id: &str, ) -> Result<RemoteProcessGroupEntity, NifiError>

Gets a remote process group

Calls GET /nifi-api/remote-process-groups/{id}.

Parameters
  • id: The remote process group id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Read - /remote-process-groups/{uuid}.

pub async fn update_remote_process_group( &self, id: &str, body: &RemoteProcessGroupEntity, ) -> Result<RemoteProcessGroupEntity, NifiError>

Updates a remote process group

Calls PUT /nifi-api/remote-process-groups/{id}.

Parameters
  • id: The remote process group id.
  • body: The remote process group configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /remote-process-groups/{uuid}.

pub async fn clear_bulletins( &self, id: &str, body: &ClearBulletinsRequestEntity, ) -> Result<ClearBulletinsResultEntity, NifiError>

Clears bulletins for a remote process group

Calls POST /nifi-api/remote-process-groups/{id}/bulletins/clear-requests.

Parameters
  • id: The remote process group id.
  • body: The clear bulletin request.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /remote-process-groups/{uuid}.

pub async fn update_remote_process_group_input_port( &self, id: &str, port_id: &str, body: &RemoteProcessGroupPortEntity, ) -> Result<RemoteProcessGroupPortEntity, NifiError>

Updates a remote port

Note: This endpoint is subject to change as NiFi and it’s REST API evolve.

Calls PUT /nifi-api/remote-process-groups/{id}/input-ports/{port-id}.

Parameters
  • id: The remote process group id.
  • port_id: The remote process group port id.
  • body: The remote process group port configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /remote-process-groups/{uuid}.

pub async fn update_remote_process_group_input_port_run_status( &self, id: &str, port_id: &str, body: &RemotePortRunStatusEntity, ) -> Result<RemoteProcessGroupPortEntity, NifiError>

Updates run status of a remote input port

Note: This endpoint is subject to change as NiFi and it’s REST API evolve.

Calls PUT /nifi-api/remote-process-groups/{id}/input-ports/{port-id}/run-status.

Parameters
  • id: The remote process group id.
  • port_id: The remote process group port id.
  • body: The remote process group port run status details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /remote-process-groups/{uuid} or /operation/remote-process-groups/{uuid}.

pub async fn update_remote_process_group_output_port( &self, id: &str, port_id: &str, body: &RemoteProcessGroupPortEntity, ) -> Result<RemoteProcessGroupPortEntity, NifiError>

Updates a remote port

Note: This endpoint is subject to change as NiFi and it’s REST API evolve.

Calls PUT /nifi-api/remote-process-groups/{id}/output-ports/{port-id}.

Parameters
  • id: The remote process group id.
  • port_id: The remote process group port id.
  • body: The remote process group port configuration details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /remote-process-groups/{uuid}.

pub async fn update_remote_process_group_output_port_run_status( &self, id: &str, port_id: &str, body: &RemotePortRunStatusEntity, ) -> Result<RemoteProcessGroupPortEntity, NifiError>

Updates run status of a remote output port

Note: This endpoint is subject to change as NiFi and it’s REST API evolve.

Calls PUT /nifi-api/remote-process-groups/{id}/output-ports/{port-id}/run-status.

Parameters
  • id: The remote process group id.
  • port_id: The remote process group port id.
  • body: The remote process group port run status details.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /remote-process-groups/{uuid} or /operation/remote-process-groups/{uuid}.

pub async fn update_remote_process_group_run_statuses( &self, id: &str, body: &RemotePortRunStatusEntity, ) -> Result<RemoteProcessGroupEntity, NifiError>

Updates run status of all remote process groups in a process group (recursively)

Calls PUT /nifi-api/remote-process-groups/process-group/{id}/run-status.

Parameters
  • id: The process group id.
  • body: The remote process groups run status.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /remote-process-groups/{uuid} or /operation/remote-process-groups/{uuid}.

pub async fn update_remote_process_group_run_status( &self, id: &str, body: &RemotePortRunStatusEntity, ) -> Result<RemoteProcessGroupEntity, NifiError>

Updates run status of a remote process group

Calls PUT /nifi-api/remote-process-groups/{id}/run-status.

Parameters
  • id: The remote process group id.
  • body: The remote process group run status.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /remote-process-groups/{uuid} or /operation/remote-process-groups/{uuid}.

pub async fn get_state(&self, id: &str) -> Result<ComponentStateDto, NifiError>

Gets the state for a RemoteProcessGroup

Calls GET /nifi-api/remote-process-groups/{id}/state.

Parameters
  • id: The processor id.
Errors
  • 400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.
  • 401: Client could not be authenticated.
  • 403: Client is not authorized to make this request.
  • 404: The specified resource could not be found.
  • 409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions

Requires Write - /remote-process-groups/{uuid}.