pub struct ControllerServices<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ControllerServices<'a>
impl<'a> ControllerServices<'a>
Sourcepub async fn get_controller_service(
&self,
id: &str,
ui_only: Option<bool>,
) -> Result<ControllerServiceEntity, NifiError>
pub async fn get_controller_service( &self, id: &str, ui_only: Option<bool>, ) -> Result<ControllerServiceEntity, NifiError>
Gets a controller service
If the uiOnly query parameter is provided with a value of true, the returned entity may only contain fields that are necessary for rendering the NiFi User Interface. As such, the selected fields may change at any time, even during incremental releases, without warning. As a result, this parameter should not be provided by any client other than the UI.
Calls GET /nifi-api/controller-services/{id}.
Parameters
id: The controller service id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller-services/{uuid}.
Sourcepub async fn get_verification_request(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn get_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Returns the Verification Request with the given ID
Returns the Verification Request with the given ID. Once an Verification Request has been created, that request can subsequently be retrieved via this endpoint, and the request that is fetched will contain the updated state, such as percent complete, the current state of the request, and any failures.
Calls GET /nifi-api/controller-services/{id}/config/verification-requests/{requestId}.
Parameters
id: The ID of the Controller Servicerequest_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can get it.
Sourcepub async fn get_property_descriptor(
&self,
id: &str,
property_name: &str,
sensitive: Option<bool>,
) -> Result<PropertyDescriptorDto, NifiError>
pub async fn get_property_descriptor( &self, id: &str, property_name: &str, sensitive: Option<bool>, ) -> Result<PropertyDescriptorDto, NifiError>
Gets a controller service property descriptor
Calls GET /nifi-api/controller-services/{id}/descriptors.
Parameters
id: The controller service id.property_name: The property name to return the descriptor for.sensitive: Property Descriptor requested sensitive status
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller-services/{uuid}.
Sourcepub async fn get_controller_service_references(
&self,
id: &str,
) -> Result<ControllerServiceReferencingComponentsEntity, NifiError>
pub async fn get_controller_service_references( &self, id: &str, ) -> Result<ControllerServiceReferencingComponentsEntity, NifiError>
Gets a controller service
Calls GET /nifi-api/controller-services/{id}/references.
Parameters
id: The controller service id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller-services/{uuid}.
Sourcepub async fn get_state(&self, id: &str) -> Result<ComponentStateDto, NifiError>
pub async fn get_state(&self, id: &str) -> Result<ComponentStateDto, NifiError>
Gets the state for a controller service
Calls GET /nifi-api/controller-services/{id}/state.
Parameters
id: The controller service id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller-services/{uuid}.
Sourcepub async fn clear_bulletins(
&self,
id: &str,
body: &ClearBulletinsRequestEntity,
) -> Result<ClearBulletinsResultEntity, NifiError>
pub async fn clear_bulletins( &self, id: &str, body: &ClearBulletinsRequestEntity, ) -> Result<ClearBulletinsResultEntity, NifiError>
Clears bulletins for a controller service
Calls POST /nifi-api/controller-services/{id}/bulletins/clear-requests.
Parameters
id: The controller service id.body: The clear bulletin request specifying the timestamp from which to clear bulletins.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller-services/{uuid}.
Sourcepub async fn analyze_configuration(
&self,
id: &str,
body: &ConfigurationAnalysisEntity,
) -> Result<ConfigurationAnalysisDto, NifiError>
pub async fn analyze_configuration( &self, id: &str, body: &ConfigurationAnalysisEntity, ) -> Result<ConfigurationAnalysisDto, NifiError>
Performs analysis of the component’s configuration, providing information about which attributes are referenced.
Calls POST /nifi-api/controller-services/{id}/config/analysis.
Parameters
id: The controller service id.body: The configuration analysis request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller-services/{uuid}.
Sourcepub async fn submit_config_verification_request(
&self,
id: &str,
body: &VerifyConfigRequestEntity,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn submit_config_verification_request( &self, id: &str, body: &VerifyConfigRequestEntity, ) -> Result<VerifyConfigRequestDto, NifiError>
Performs verification of the Controller Service’s configuration
This will initiate the process of verifying a given Controller Service configuration. This may be a long-running task. As a result, this endpoint will immediately return a ControllerServiceConfigVerificationRequestEntity, and the process of performing the verification will occur asynchronously in the background. The client may then periodically poll the status of the request by issuing a GET request to /controller-services/{serviceId}/verification-requests/{requestId}. Once the request is completed, the client is expected to issue a DELETE request to /controller-services/{serviceId}/verification-requests/{requestId}.
Calls POST /nifi-api/controller-services/{id}/config/verification-requests.
Parameters
id: The controller service id.body: The controller service configuration verification request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller-services/{uuid}.
Sourcepub async fn clear_state(
&self,
id: &str,
body: &ComponentStateEntity,
) -> Result<ComponentStateDto, NifiError>
pub async fn clear_state( &self, id: &str, body: &ComponentStateEntity, ) -> Result<ComponentStateDto, NifiError>
Clears the state for a controller service
Calls POST /nifi-api/controller-services/{id}/state/clear-requests.
Parameters
id: The controller service id.body: Optional component state to perform a selective key removal. If omitted, clears all state.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller-services/{uuid}.
Sourcepub async fn update_controller_service(
&self,
id: &str,
body: &ControllerServiceEntity,
) -> Result<ControllerServiceEntity, NifiError>
pub async fn update_controller_service( &self, id: &str, body: &ControllerServiceEntity, ) -> Result<ControllerServiceEntity, NifiError>
Updates a controller service
Calls PUT /nifi-api/controller-services/{id}.
Parameters
id: The controller service id.body: The controller service configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controller-services/{uuid}Read - any referenced Controller Services if this request changes the reference - /controller-services/{uuid}
Sourcepub async fn update_controller_service_references(
&self,
id: &str,
body: &UpdateControllerServiceReferenceRequestEntity,
) -> Result<ControllerServiceReferencingComponentsEntity, NifiError>
pub async fn update_controller_service_references( &self, id: &str, body: &UpdateControllerServiceReferenceRequestEntity, ) -> Result<ControllerServiceReferencingComponentsEntity, NifiError>
Updates a controller services references
Calls PUT /nifi-api/controller-services/{id}/references.
Parameters
id: The controller service id.body: The controller service request update request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /{component-type}/{uuid} or /operate/{component-type}/{uuid} - For each referencing component specified.
Sourcepub async fn update_run_status(
&self,
id: &str,
body: &ControllerServiceRunStatusEntity,
) -> Result<ControllerServiceEntity, NifiError>
pub async fn update_run_status( &self, id: &str, body: &ControllerServiceRunStatusEntity, ) -> Result<ControllerServiceEntity, NifiError>
Updates run status of a controller service
Calls PUT /nifi-api/controller-services/{id}/run-status.
Parameters
id: The controller service id.body: The controller service run status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller-services/{uuid} or /operation/controller-services/{uuid}.
Sourcepub async fn remove_controller_service(
&self,
id: &str,
version: Option<&str>,
client_id: Option<&str>,
disconnected_node_acknowledged: Option<bool>,
) -> Result<ControllerServiceEntity, NifiError>
pub async fn remove_controller_service( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<ControllerServiceEntity, NifiError>
Deletes a controller service
Calls DELETE /nifi-api/controller-services/{id}.
Parameters
id: The controller service id.version: The revision is used to verify the client is working with the latest version of the flow.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controller-services/{uuid}Write - Parent Process Group if scoped by Process Group - /process-groups/{uuid}Write - Controller if scoped by Controller - /controllerRead - any referenced Controller Services - /controller-services/{uuid}
Sourcepub async fn delete_verification_request(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn delete_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Deletes the Verification Request with the given ID
Deletes the Verification Request with the given ID. After a request is created, it is expected that the client will properly clean up the request by DELETE’ing it, once the Verification process has completed. If the request is deleted before the request completes, then the Verification request will finish the step that it is currently performing and then will cancel any subsequent steps.
Calls DELETE /nifi-api/controller-services/{id}/config/verification-requests/{requestId}.
Parameters
id: The ID of the Controller Servicerequest_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can remove it.