pub struct InputPorts<'a> { /* private fields */ }Implementations
Sourceimpl<'a> InputPorts<'a>
impl<'a> InputPorts<'a>
Sourcepub async fn get_input_port(&self, id: &str) -> Result<PortEntity, NifiError>
pub async fn get_input_port(&self, id: &str) -> Result<PortEntity, NifiError>
Gets an input port
Calls GET /nifi-api/input-ports/{id}.
Parameters
id: The input port id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /input-ports/{uuid}.
Sourcepub async fn clear_bulletins(
&self,
id: &str,
body: &ClearBulletinsRequestEntity,
) -> Result<ClearBulletinsResultEntity, NifiError>
pub async fn clear_bulletins( &self, id: &str, body: &ClearBulletinsRequestEntity, ) -> Result<ClearBulletinsResultEntity, NifiError>
Clears bulletins for an input port
Calls POST /nifi-api/input-ports/{id}/bulletins/clear-requests.
Parameters
id: The input port id.body: The request to clear bulletins.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /input-ports/{uuid}.
Sourcepub async fn update_input_port(
&self,
id: &str,
body: &PortEntity,
) -> Result<PortEntity, NifiError>
pub async fn update_input_port( &self, id: &str, body: &PortEntity, ) -> Result<PortEntity, NifiError>
Updates an input port
Calls PUT /nifi-api/input-ports/{id}.
Parameters
id: The input port id.body: The input port configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /input-ports/{uuid}.
Sourcepub async fn update_run_status(
&self,
id: &str,
body: &PortRunStatusEntity,
) -> Result<ProcessorEntity, NifiError>
pub async fn update_run_status( &self, id: &str, body: &PortRunStatusEntity, ) -> Result<ProcessorEntity, NifiError>
Updates run status of an input-port
Calls PUT /nifi-api/input-ports/{id}/run-status.
Parameters
id: The port id.body: The port run status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /input-ports/{uuid} or /operation/input-ports/{uuid}.
Sourcepub async fn remove_input_port(
&self,
id: &str,
version: Option<&str>,
client_id: Option<&str>,
disconnected_node_acknowledged: Option<bool>,
) -> Result<PortEntity, NifiError>
pub async fn remove_input_port( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<PortEntity, NifiError>
Deletes an input port
Calls DELETE /nifi-api/input-ports/{id}.
Parameters
id: The input port id.version: The revision is used to verify the client is working with the latest version of the flow.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /input-ports/{uuid}Write - Parent Process Group - /process-groups/{uuid}