pub struct Processors<'a> { /* private fields */ }Implementations
Sourceimpl<'a> Processors<'a>
impl<'a> Processors<'a>
Sourcepub async fn get_processor(
&self,
id: &str,
) -> Result<ProcessorEntity, NifiError>
pub async fn get_processor( &self, id: &str, ) -> Result<ProcessorEntity, NifiError>
Gets a processor
Calls GET /nifi-api/processors/{id}.
Parameters
id: The processor id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /processors/{uuid}.
Sourcepub async fn get_verification_request(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn get_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Returns the Verification Request with the given ID
Returns the Verification Request with the given ID. Once an Verification Request has been created, that request can subsequently be retrieved via this endpoint, and the request that is fetched will contain the updated state, such as percent complete, the current state of the request, and any failures.
Calls GET /nifi-api/processors/{id}/config/verification-requests/{requestId}.
Parameters
id: The ID of the Processorrequest_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can get it.
Sourcepub async fn get_property_descriptor(
&self,
id: &str,
client_id: Option<&str>,
property_name: &str,
sensitive: Option<bool>,
) -> Result<PropertyDescriptorDto, NifiError>
pub async fn get_property_descriptor( &self, id: &str, client_id: Option<&str>, property_name: &str, sensitive: Option<bool>, ) -> Result<PropertyDescriptorDto, NifiError>
Gets the descriptor for a processor property
Calls GET /nifi-api/processors/{id}/descriptors.
Parameters
id: The processor id.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.property_name: The property name.sensitive: Property Descriptor requested sensitive status
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /processors/{uuid}.
Sourcepub async fn get_processor_diagnostics(
&self,
id: &str,
) -> Result<ProcessorEntity, NifiError>
pub async fn get_processor_diagnostics( &self, id: &str, ) -> Result<ProcessorEntity, NifiError>
Gets diagnostics information about a processor
Note: This endpoint is subject to change as NiFi and it’s REST API evolve.
Calls GET /nifi-api/processors/{id}/diagnostics.
Parameters
id: The processor id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /processors/{uuid}.
Sourcepub async fn get_state(&self, id: &str) -> Result<ComponentStateDto, NifiError>
pub async fn get_state(&self, id: &str) -> Result<ComponentStateDto, NifiError>
Gets the state for a processor
Calls GET /nifi-api/processors/{id}/state.
Parameters
id: The processor id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /processors/{uuid}.
Sourcepub async fn get_processor_run_status_details(
&self,
body: &RunStatusDetailsRequestEntity,
) -> Result<ProcessorsRunStatusDetailsEntity, NifiError>
pub async fn get_processor_run_status_details( &self, body: &RunStatusDetailsRequestEntity, ) -> Result<ProcessorsRunStatusDetailsEntity, NifiError>
Submits a query to retrieve the run status details of all processors that are in the given list of Processor IDs
Calls POST /nifi-api/processors/run-status-details/queries.
Parameters
body: The request for the processors that should be included in the results
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /processors/{uuid} for each processor whose run status information is requested.
Sourcepub async fn clear_bulletins(
&self,
id: &str,
body: &ClearBulletinsRequestEntity,
) -> Result<ClearBulletinsResultEntity, NifiError>
pub async fn clear_bulletins( &self, id: &str, body: &ClearBulletinsRequestEntity, ) -> Result<ClearBulletinsResultEntity, NifiError>
Clears bulletins for a processor
Calls POST /nifi-api/processors/{id}/bulletins/clear-requests.
Parameters
id: The processor id.body: The clear bulletin request specifying the timestamp from which to clear bulletins.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /processors/{uuid}.
Sourcepub async fn analyze_configuration(
&self,
id: &str,
body: &ConfigurationAnalysisEntity,
) -> Result<ConfigurationAnalysisDto, NifiError>
pub async fn analyze_configuration( &self, id: &str, body: &ConfigurationAnalysisEntity, ) -> Result<ConfigurationAnalysisDto, NifiError>
Performs analysis of the component’s configuration, providing information about which attributes are referenced.
Calls POST /nifi-api/processors/{id}/config/analysis.
Parameters
id: The processor id.body: The processor configuration analysis request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /processors/{uuid}.
Sourcepub async fn submit_processor_verification_request(
&self,
id: &str,
body: &VerifyConfigRequestEntity,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn submit_processor_verification_request( &self, id: &str, body: &VerifyConfigRequestEntity, ) -> Result<VerifyConfigRequestDto, NifiError>
Performs verification of the Processor’s configuration
This will initiate the process of verifying a given Processor configuration. This may be a long-running task. As a result, this endpoint will immediately return a ProcessorConfigVerificationRequestEntity, and the process of performing the verification will occur asynchronously in the background. The client may then periodically poll the status of the request by issuing a GET request to /processors/{processorId}/verification-requests/{requestId}. Once the request is completed, the client is expected to issue a DELETE request to /processors/{processorId}/verification-requests/{requestId}.
Calls POST /nifi-api/processors/{id}/config/verification-requests.
Parameters
id: The processor id.body: The processor configuration verification request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /processors/{uuid}.
Sourcepub async fn clear_state(
&self,
id: &str,
body: &ComponentStateEntity,
) -> Result<ComponentStateDto, NifiError>
pub async fn clear_state( &self, id: &str, body: &ComponentStateEntity, ) -> Result<ComponentStateDto, NifiError>
Clears the state for a processor
Calls POST /nifi-api/processors/{id}/state/clear-requests.
Parameters
id: The processor id.body: Optional component state to perform a selective key removal. If omitted, clears all state.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /processors/{uuid}.
Sourcepub async fn update_processor(
&self,
id: &str,
body: &ProcessorEntity,
) -> Result<ProcessorEntity, NifiError>
pub async fn update_processor( &self, id: &str, body: &ProcessorEntity, ) -> Result<ProcessorEntity, NifiError>
Updates a processor
Calls PUT /nifi-api/processors/{id}.
Parameters
id: The processor id.body: The processor configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /processors/{uuid}Read - any referenced Controller Services if this request changes the reference - /controller-services/{uuid}
Sourcepub async fn update_run_status(
&self,
id: &str,
body: &ProcessorRunStatusEntity,
) -> Result<ProcessorEntity, NifiError>
pub async fn update_run_status( &self, id: &str, body: &ProcessorRunStatusEntity, ) -> Result<ProcessorEntity, NifiError>
Updates run status of a processor
Calls PUT /nifi-api/processors/{id}/run-status.
Parameters
id: The processor id.body: The processor run status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /processors/{uuid} or /operation/processors/{uuid}.
Sourcepub async fn delete_processor(
&self,
id: &str,
version: Option<&str>,
client_id: Option<&str>,
disconnected_node_acknowledged: Option<bool>,
) -> Result<ProcessorEntity, NifiError>
pub async fn delete_processor( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<ProcessorEntity, NifiError>
Deletes a processor
Calls DELETE /nifi-api/processors/{id}.
Parameters
id: The processor id.version: The revision is used to verify the client is working with the latest version of the flow.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /processors/{uuid}Write - Parent Process Group - /process-groups/{uuid}Read - any referenced Controller Services - /controller-services/{uuid}
Sourcepub async fn delete_verification_request(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn delete_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Deletes the Verification Request with the given ID
Deletes the Verification Request with the given ID. After a request is created, it is expected that the client will properly clean up the request by DELETE’ing it, once the Verification process has completed. If the request is deleted before the request completes, then the Verification request will finish the step that it is currently performing and then will cancel any subsequent steps.
Calls DELETE /nifi-api/processors/{id}/config/verification-requests/{requestId}.
Parameters
id: The ID of the Processorrequest_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can remove it.
Sourcepub async fn terminate_processor(
&self,
id: &str,
) -> Result<ProcessorEntity, NifiError>
pub async fn terminate_processor( &self, id: &str, ) -> Result<ProcessorEntity, NifiError>
Terminates a processor, essentially “deleting” its threads and any active tasks
Calls DELETE /nifi-api/processors/{id}/threads.
Parameters
id: The processor id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /processors/{uuid} or /operation/processors/{uuid}.