pub struct ReportingTasks<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ReportingTasks<'a>
impl<'a> ReportingTasks<'a>
Sourcepub async fn get_reporting_task(
&self,
id: &str,
) -> Result<ReportingTaskEntity, NifiError>
pub async fn get_reporting_task( &self, id: &str, ) -> Result<ReportingTaskEntity, NifiError>
Gets a reporting task
Calls GET /nifi-api/reporting-tasks/{id}.
Parameters
id: The reporting task id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /reporting-tasks/{uuid}.
Sourcepub async fn get_verification_request(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn get_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Returns the Verification Request with the given ID
Returns the Verification Request with the given ID. Once an Verification Request has been created, that request can subsequently be retrieved via this endpoint, and the request that is fetched will contain the updated state, such as percent complete, the current state of the request, and any failures.
Calls GET /nifi-api/reporting-tasks/{id}/config/verification-requests/{requestId}.
Parameters
id: The ID of the Reporting Taskrequest_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can get it.
Sourcepub async fn get_property_descriptor(
&self,
id: &str,
property_name: &str,
sensitive: Option<bool>,
) -> Result<PropertyDescriptorDto, NifiError>
pub async fn get_property_descriptor( &self, id: &str, property_name: &str, sensitive: Option<bool>, ) -> Result<PropertyDescriptorDto, NifiError>
Gets a reporting task property descriptor
Calls GET /nifi-api/reporting-tasks/{id}/descriptors.
Parameters
id: The reporting task id.property_name: The property name.sensitive: Property Descriptor requested sensitive status
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /reporting-tasks/{uuid}.
Sourcepub async fn get_state(&self, id: &str) -> Result<ComponentStateDto, NifiError>
pub async fn get_state(&self, id: &str) -> Result<ComponentStateDto, NifiError>
Gets the state for a reporting task
Calls GET /nifi-api/reporting-tasks/{id}/state.
Parameters
id: The reporting task id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /reporting-tasks/{uuid}.
Sourcepub async fn clear_bulletins(
&self,
id: &str,
body: &ClearBulletinsRequestEntity,
) -> Result<ClearBulletinsResultEntity, NifiError>
pub async fn clear_bulletins( &self, id: &str, body: &ClearBulletinsRequestEntity, ) -> Result<ClearBulletinsResultEntity, NifiError>
Clears bulletins for a reporting task
Calls POST /nifi-api/reporting-tasks/{id}/bulletins/clear-requests.
Parameters
id: The reporting task id.body: The clear bulletin request specifying the timestamp from which to clear bulletins.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /reporting-tasks/{uuid}.
Sourcepub async fn analyze_configuration(
&self,
id: &str,
body: &ConfigurationAnalysisEntity,
) -> Result<ConfigurationAnalysisDto, NifiError>
pub async fn analyze_configuration( &self, id: &str, body: &ConfigurationAnalysisEntity, ) -> Result<ConfigurationAnalysisDto, NifiError>
Performs analysis of the component’s configuration, providing information about which attributes are referenced.
Calls POST /nifi-api/reporting-tasks/{id}/config/analysis.
Parameters
id: The reporting task id.body: The configuration analysis request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /reporting-tasks/{uuid}.
Sourcepub async fn submit_config_verification_request(
&self,
id: &str,
body: &VerifyConfigRequestEntity,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn submit_config_verification_request( &self, id: &str, body: &VerifyConfigRequestEntity, ) -> Result<VerifyConfigRequestDto, NifiError>
Performs verification of the Reporting Task’s configuration
This will initiate the process of verifying a given Reporting Task configuration. This may be a long-running task. As a result, this endpoint will immediately return a ReportingTaskConfigVerificationRequestEntity, and the process of performing the verification will occur asynchronously in the background. The client may then periodically poll the status of the request by issuing a GET request to /reporting-tasks/{taskId}/verification-requests/{requestId}. Once the request is completed, the client is expected to issue a DELETE request to /reporting-tasks/{serviceId}/verification-requests/{requestId}.
Calls POST /nifi-api/reporting-tasks/{id}/config/verification-requests.
Parameters
id: The reporting task id.body: The reporting task configuration verification request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /reporting-tasks/{uuid}.
Sourcepub async fn clear_state(
&self,
id: &str,
body: &ComponentStateEntity,
) -> Result<ComponentStateDto, NifiError>
pub async fn clear_state( &self, id: &str, body: &ComponentStateEntity, ) -> Result<ComponentStateDto, NifiError>
Clears the state for a reporting task
Calls POST /nifi-api/reporting-tasks/{id}/state/clear-requests.
Parameters
id: The reporting task id.body: Optional component state to perform a selective key removal. If omitted, clears all state.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /reporting-tasks/{uuid}.
Sourcepub async fn update_reporting_task(
&self,
id: &str,
body: &ReportingTaskEntity,
) -> Result<ReportingTaskEntity, NifiError>
pub async fn update_reporting_task( &self, id: &str, body: &ReportingTaskEntity, ) -> Result<ReportingTaskEntity, NifiError>
Updates a reporting task
Calls PUT /nifi-api/reporting-tasks/{id}.
Parameters
id: The reporting task id.body: The reporting task configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /reporting-tasks/{uuid}Read - any referenced Controller Services if this request changes the reference - /controller-services/{uuid}
Sourcepub async fn update_run_status(
&self,
id: &str,
body: &ReportingTaskRunStatusEntity,
) -> Result<ReportingTaskEntity, NifiError>
pub async fn update_run_status( &self, id: &str, body: &ReportingTaskRunStatusEntity, ) -> Result<ReportingTaskEntity, NifiError>
Updates run status of a reporting task
Calls PUT /nifi-api/reporting-tasks/{id}/run-status.
Parameters
id: The reporting task id.body: The reporting task run status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /reporting-tasks/{uuid} or or /operation/reporting-tasks/{uuid}.
Sourcepub async fn remove_reporting_task(
&self,
id: &str,
version: Option<&str>,
client_id: Option<&str>,
disconnected_node_acknowledged: Option<bool>,
) -> Result<ReportingTaskEntity, NifiError>
pub async fn remove_reporting_task( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<ReportingTaskEntity, NifiError>
Deletes a reporting task
Calls DELETE /nifi-api/reporting-tasks/{id}.
Parameters
id: The reporting task id.version: The revision is used to verify the client is working with the latest version of the flow.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /reporting-tasks/{uuid}Write - /controllerRead - any referenced Controller Services - /controller-services/{uuid}
Sourcepub async fn delete_verification_request(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn delete_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Deletes the Verification Request with the given ID
Deletes the Verification Request with the given ID. After a request is created, it is expected that the client will properly clean up the request by DELETE’ing it, once the Verification process has completed. If the request is deleted before the request completes, then the Verification request will finish the step that it is currently performing and then will cancel any subsequent steps.
Calls DELETE /nifi-api/reporting-tasks/{id}/config/verification-requests/{requestId}.
Parameters
id: The ID of the Reporting Taskrequest_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can remove it.