pub struct SystemDiagnostics<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SystemDiagnostics<'a>
impl<'a> SystemDiagnostics<'a>
Sourcepub async fn get_system_diagnostics(
&self,
nodewise: Option<bool>,
diagnostic_level: Option<DiagnosticLevel>,
cluster_node_id: Option<&str>,
) -> Result<SystemDiagnosticsDto, NifiError>
pub async fn get_system_diagnostics( &self, nodewise: Option<bool>, diagnostic_level: Option<DiagnosticLevel>, cluster_node_id: Option<&str>, ) -> Result<SystemDiagnosticsDto, NifiError>
Gets the diagnostics for the system NiFi is running on
Calls GET /nifi-api/system-diagnostics.
Parameters
nodewise: Whether or not to include the breakdown per node. Optional, defaults to falsediagnostic_level: BASIC or VERBOSE verbosity details. Optional, defaults to BASICcluster_node_id: The id of the node where to get the status.
Errors
401: Client could not be authenticated.403: Client is not authorized to make this request.
Permissions
Requires Read - /system.
Sourcepub async fn get_jmx_metrics(
&self,
bean_name_filter: Option<&str>,
) -> Result<JmxMetricsResultsEntity, NifiError>
pub async fn get_jmx_metrics( &self, bean_name_filter: Option<&str>, ) -> Result<JmxMetricsResultsEntity, NifiError>
Retrieve available JMX metrics
Note: This endpoint is subject to change as NiFi and it’s REST API evolve.
Calls GET /nifi-api/system-diagnostics/jmx-metrics.
Parameters
bean_name_filter: Regular Expression Pattern to be applied against the ObjectName
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /system.