pub struct DynamicFlowApi<'a> { /* private fields */ }Expand description
Dynamic dispatch wrapper for the Flow API.
Implementations
Sourceimpl<'a> DynamicFlowApi<'a>
impl<'a> DynamicFlowApi<'a>
Sourcepub async fn activate_controller_services(
&self,
id: &str,
body: &Value,
) -> Result<ActivateControllerServicesEntity, NifiError>
pub async fn activate_controller_services( &self, id: &str, body: &Value, ) -> Result<ActivateControllerServicesEntity, NifiError>
Enable or disable Controller Services in the specified Process Group.
Sourcepub async fn clear_bulletins_1(
&self,
id: &str,
body: &Value,
) -> Result<ClearBulletinsForGroupResultsEntity, NifiError>
pub async fn clear_bulletins_1( &self, id: &str, body: &Value, ) -> Result<ClearBulletinsForGroupResultsEntity, NifiError>
Clears bulletins for components in the specified Process Group.
Sourcepub async fn download_reporting_task_snapshot(
&self,
reporting_task_id: Option<&str>,
) -> Result<(), NifiError>
pub async fn download_reporting_task_snapshot( &self, reporting_task_id: Option<&str>, ) -> Result<(), NifiError>
Download a snapshot of the given reporting tasks and any controller services they use
Sourcepub async fn generate_client_id(&self) -> Result<(), NifiError>
pub async fn generate_client_id(&self) -> Result<(), NifiError>
Generates a client id.
Sourcepub async fn get_about_info(&self) -> Result<AboutDto, NifiError>
pub async fn get_about_info(&self) -> Result<AboutDto, NifiError>
Retrieves details about this NiFi to put in the About dialog
Sourcepub async fn get_action(&self, id: &str) -> Result<ActionEntity, NifiError>
pub async fn get_action(&self, id: &str) -> Result<ActionEntity, NifiError>
Gets an action
Sourcepub async fn get_additional_details(
&self,
group: &str,
artifact: &str,
version: &str,
type: &str,
) -> Result<AdditionalDetailsEntity, NifiError>
pub async fn get_additional_details( &self, group: &str, artifact: &str, version: &str, type: &str, ) -> Result<AdditionalDetailsEntity, NifiError>
Retrieves the additional details for the specified component type.
Sourcepub async fn get_all_flow_analysis_results(
&self,
) -> Result<FlowAnalysisResultEntity, NifiError>
pub async fn get_all_flow_analysis_results( &self, ) -> Result<FlowAnalysisResultEntity, NifiError>
Returns all flow analysis results currently in effect
Retrieves the banners for this NiFi
Sourcepub async fn get_branches(
&self,
id: &str,
) -> Result<FlowRegistryBranchesEntity, NifiError>
pub async fn get_branches( &self, id: &str, ) -> Result<FlowRegistryBranchesEntity, NifiError>
Gets the branches from the specified registry for the current user
Gets the breadcrumbs for a process group
Sourcepub async fn get_buckets(
&self,
id: &str,
branch: Option<&str>,
) -> Result<FlowRegistryBucketsEntity, NifiError>
pub async fn get_buckets( &self, id: &str, branch: Option<&str>, ) -> Result<FlowRegistryBucketsEntity, NifiError>
Gets the buckets from the specified registry for the current user
Sourcepub async fn get_bulletin_board(
&self,
after: Option<&str>,
source_name: Option<&str>,
message: Option<&str>,
source_id: Option<&str>,
group_id: Option<&str>,
limit: Option<&str>,
) -> Result<BulletinBoardDto, NifiError>
pub async fn get_bulletin_board( &self, after: Option<&str>, source_name: Option<&str>, message: Option<&str>, source_id: Option<&str>, group_id: Option<&str>, limit: Option<&str>, ) -> Result<BulletinBoardDto, NifiError>
Gets current bulletins
Sourcepub async fn get_bulletins(
&self,
) -> Result<ControllerBulletinsEntity, NifiError>
pub async fn get_bulletins( &self, ) -> Result<ControllerBulletinsEntity, NifiError>
Retrieves Controller level bulletins
Sourcepub async fn get_cluster_summary(&self) -> Result<ClusterSummaryDto, NifiError>
pub async fn get_cluster_summary(&self) -> Result<ClusterSummaryDto, NifiError>
The cluster summary for this NiFi
Sourcepub async fn get_component_history(
&self,
component_id: &str,
) -> Result<ComponentHistoryDto, NifiError>
pub async fn get_component_history( &self, component_id: &str, ) -> Result<ComponentHistoryDto, NifiError>
Gets configuration history for a component
Sourcepub async fn get_connection_statistics(
&self,
id: &str,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<ConnectionStatisticsEntity, NifiError>
pub async fn get_connection_statistics( &self, id: &str, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<ConnectionStatisticsEntity, NifiError>
Gets statistics for a connection
Sourcepub async fn get_connection_status(
&self,
id: &str,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<ConnectionStatusEntity, NifiError>
pub async fn get_connection_status( &self, id: &str, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<ConnectionStatusEntity, NifiError>
Gets status for a connection
Sourcepub async fn get_connection_status_history(
&self,
id: &str,
) -> Result<StatusHistoryEntity, NifiError>
pub async fn get_connection_status_history( &self, id: &str, ) -> Result<StatusHistoryEntity, NifiError>
Gets the status history for a connection
Sourcepub async fn get_content_viewers(
&self,
) -> Result<ContentViewerEntity, NifiError>
pub async fn get_content_viewers( &self, ) -> Result<ContentViewerEntity, NifiError>
Retrieves the registered content viewers
Sourcepub async fn get_controller_service_definition(
&self,
group: &str,
artifact: &str,
version: &str,
type: &str,
) -> Result<ControllerServiceDefinition, NifiError>
pub async fn get_controller_service_definition( &self, group: &str, artifact: &str, version: &str, type: &str, ) -> Result<ControllerServiceDefinition, NifiError>
Retrieves the Controller Service Definition for the specified component type.
Sourcepub async fn get_controller_service_types(
&self,
service_type: Option<&str>,
service_bundle_group: Option<&str>,
service_bundle_artifact: Option<&str>,
service_bundle_version: Option<&str>,
bundle_group_filter: Option<&str>,
bundle_artifact_filter: Option<&str>,
type_filter: Option<&str>,
) -> Result<ControllerServiceTypesEntity, NifiError>
pub async fn get_controller_service_types( &self, service_type: Option<&str>, service_bundle_group: Option<&str>, service_bundle_artifact: Option<&str>, service_bundle_version: Option<&str>, bundle_group_filter: Option<&str>, bundle_artifact_filter: Option<&str>, type_filter: Option<&str>, ) -> Result<ControllerServiceTypesEntity, NifiError>
Retrieves the types of controller services that this NiFi supports
Sourcepub async fn get_controller_services_from_controller(
&self,
ui_only: Option<bool>,
include_referencing_components: Option<bool>,
) -> Result<ControllerServicesEntity, NifiError>
pub async fn get_controller_services_from_controller( &self, ui_only: Option<bool>, include_referencing_components: Option<bool>, ) -> Result<ControllerServicesEntity, NifiError>
Gets controller services for reporting tasks
Sourcepub async fn get_controller_services_from_group(
&self,
id: &str,
include_ancestor_groups: Option<bool>,
include_descendant_groups: Option<bool>,
include_referencing_components: Option<bool>,
ui_only: Option<bool>,
) -> Result<ControllerServicesEntity, NifiError>
pub async fn get_controller_services_from_group( &self, id: &str, include_ancestor_groups: Option<bool>, include_descendant_groups: Option<bool>, include_referencing_components: Option<bool>, ui_only: Option<bool>, ) -> Result<ControllerServicesEntity, NifiError>
Gets all controller services
Sourcepub async fn get_controller_status(
&self,
) -> Result<ControllerStatusDto, NifiError>
pub async fn get_controller_status( &self, ) -> Result<ControllerStatusDto, NifiError>
Gets the current status of this NiFi
Sourcepub async fn get_current_user(&self) -> Result<CurrentUserEntity, NifiError>
pub async fn get_current_user(&self) -> Result<CurrentUserEntity, NifiError>
Retrieves the user identity of the user making the request
Sourcepub async fn get_details(
&self,
id: &str,
registry_id: &str,
bucket_id: &str,
flow_id: &str,
branch: Option<&str>,
) -> Result<VersionedFlowDto, NifiError>
pub async fn get_details( &self, id: &str, registry_id: &str, bucket_id: &str, flow_id: &str, branch: Option<&str>, ) -> Result<VersionedFlowDto, NifiError>
Gets the details of a flow from the specified registry and bucket for the specified flow for the current user
Sourcepub async fn get_flow(
&self,
id: &str,
ui_only: Option<bool>,
) -> Result<ProcessGroupFlowEntity, NifiError>
pub async fn get_flow( &self, id: &str, ui_only: Option<bool>, ) -> Result<ProcessGroupFlowEntity, NifiError>
Gets a process group
Sourcepub async fn get_flow_analysis_results(
&self,
process_group_id: &str,
) -> Result<FlowAnalysisResultEntity, NifiError>
pub async fn get_flow_analysis_results( &self, process_group_id: &str, ) -> Result<FlowAnalysisResultEntity, NifiError>
Returns flow analysis results produced by the analysis of a given process group
Sourcepub async fn get_flow_analysis_rule_definition(
&self,
group: &str,
artifact: &str,
version: &str,
type: &str,
) -> Result<FlowAnalysisRuleDefinition, NifiError>
pub async fn get_flow_analysis_rule_definition( &self, group: &str, artifact: &str, version: &str, type: &str, ) -> Result<FlowAnalysisRuleDefinition, NifiError>
Retrieves the Flow Analysis Rule Definition for the specified component type.
Sourcepub async fn get_flow_analysis_rule_types(
&self,
bundle_group_filter: Option<&str>,
bundle_artifact_filter: Option<&str>,
type: Option<&str>,
) -> Result<FlowAnalysisRuleTypesEntity, NifiError>
pub async fn get_flow_analysis_rule_types( &self, bundle_group_filter: Option<&str>, bundle_artifact_filter: Option<&str>, type: Option<&str>, ) -> Result<FlowAnalysisRuleTypesEntity, NifiError>
Retrieves the types of available Flow Analysis Rules
Sourcepub async fn get_flow_config(&self) -> Result<FlowConfigurationDto, NifiError>
pub async fn get_flow_config(&self) -> Result<FlowConfigurationDto, NifiError>
Retrieves the configuration for this NiFi flow
Sourcepub async fn get_flow_metrics(
&self,
producer: &str,
included_registries: Option<&str>,
sample_name: Option<&str>,
sample_label_value: Option<&str>,
root_field_name: Option<&str>,
flow_metrics_reporting_strategy: Option<&str>,
) -> Result<(), NifiError>
pub async fn get_flow_metrics( &self, producer: &str, included_registries: Option<&str>, sample_name: Option<&str>, sample_label_value: Option<&str>, root_field_name: Option<&str>, flow_metrics_reporting_strategy: Option<&str>, ) -> Result<(), NifiError>
Gets all metrics for the flow from a particular node
Sourcepub async fn get_flow_registry_client_definition(
&self,
group: &str,
artifact: &str,
version: &str,
type: &str,
) -> Result<FlowRegistryClientDefinition, NifiError>
pub async fn get_flow_registry_client_definition( &self, group: &str, artifact: &str, version: &str, type: &str, ) -> Result<FlowRegistryClientDefinition, NifiError>
Retrieves the Flow Registry Client Definition for the specified component type.
Sourcepub async fn get_flows(
&self,
id: &str,
registry_id: &str,
bucket_id: &str,
branch: Option<&str>,
) -> Result<VersionedFlowsEntity, NifiError>
pub async fn get_flows( &self, id: &str, registry_id: &str, bucket_id: &str, branch: Option<&str>, ) -> Result<VersionedFlowsEntity, NifiError>
Gets the flows from the specified registry and bucket for the current user
Sourcepub async fn get_input_port_status(
&self,
id: &str,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<PortStatusEntity, NifiError>
pub async fn get_input_port_status( &self, id: &str, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<PortStatusEntity, NifiError>
Gets status for an input port
Sourcepub async fn get_listen_ports(&self) -> Result<ListenPortsEntity, NifiError>
pub async fn get_listen_ports(&self) -> Result<ListenPortsEntity, NifiError>
Gets all listen ports configured on this NiFi that the current user has access to
Sourcepub async fn get_output_port_status(
&self,
id: &str,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<PortStatusEntity, NifiError>
pub async fn get_output_port_status( &self, id: &str, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<PortStatusEntity, NifiError>
Gets status for an output port
Sourcepub async fn get_parameter_contexts(
&self,
) -> Result<ParameterContextsEntity, NifiError>
pub async fn get_parameter_contexts( &self, ) -> Result<ParameterContextsEntity, NifiError>
Gets all Parameter Contexts
Sourcepub async fn get_parameter_provider_definition(
&self,
group: &str,
artifact: &str,
version: &str,
type: &str,
) -> Result<ParameterProviderDefinition, NifiError>
pub async fn get_parameter_provider_definition( &self, group: &str, artifact: &str, version: &str, type: &str, ) -> Result<ParameterProviderDefinition, NifiError>
Retrieves the Parameter Provider Definition for the specified component type.
Sourcepub async fn get_parameter_provider_types(
&self,
bundle_group_filter: Option<&str>,
bundle_artifact_filter: Option<&str>,
type: Option<&str>,
) -> Result<ParameterProviderTypesEntity, NifiError>
pub async fn get_parameter_provider_types( &self, bundle_group_filter: Option<&str>, bundle_artifact_filter: Option<&str>, type: Option<&str>, ) -> Result<ParameterProviderTypesEntity, NifiError>
Retrieves the types of parameter providers that this NiFi supports
Sourcepub async fn get_parameter_providers(
&self,
) -> Result<ParameterProvidersEntity, NifiError>
pub async fn get_parameter_providers( &self, ) -> Result<ParameterProvidersEntity, NifiError>
Gets all parameter providers
Sourcepub async fn get_prioritizers(
&self,
) -> Result<PrioritizerTypesEntity, NifiError>
pub async fn get_prioritizers( &self, ) -> Result<PrioritizerTypesEntity, NifiError>
Retrieves the types of prioritizers that this NiFi supports
Sourcepub async fn get_process_group_status(
&self,
id: &str,
recursive: Option<bool>,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<ProcessGroupStatusEntity, NifiError>
pub async fn get_process_group_status( &self, id: &str, recursive: Option<bool>, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<ProcessGroupStatusEntity, NifiError>
Gets the status for a process group
Sourcepub async fn get_process_group_status_history(
&self,
id: &str,
) -> Result<StatusHistoryEntity, NifiError>
pub async fn get_process_group_status_history( &self, id: &str, ) -> Result<StatusHistoryEntity, NifiError>
Gets status history for a remote process group
Sourcepub async fn get_processor_definition(
&self,
group: &str,
artifact: &str,
version: &str,
type: &str,
) -> Result<ProcessorDefinition, NifiError>
pub async fn get_processor_definition( &self, group: &str, artifact: &str, version: &str, type: &str, ) -> Result<ProcessorDefinition, NifiError>
Retrieves the Processor Definition for the specified component type.
Sourcepub async fn get_processor_status(
&self,
id: &str,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<ProcessorStatusEntity, NifiError>
pub async fn get_processor_status( &self, id: &str, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<ProcessorStatusEntity, NifiError>
Gets status for a processor
Sourcepub async fn get_processor_status_history(
&self,
id: &str,
) -> Result<StatusHistoryEntity, NifiError>
pub async fn get_processor_status_history( &self, id: &str, ) -> Result<StatusHistoryEntity, NifiError>
Gets status history for a processor
Sourcepub async fn get_processor_types(
&self,
bundle_group_filter: Option<&str>,
bundle_artifact_filter: Option<&str>,
type: Option<&str>,
) -> Result<ProcessorTypesEntity, NifiError>
pub async fn get_processor_types( &self, bundle_group_filter: Option<&str>, bundle_artifact_filter: Option<&str>, type: Option<&str>, ) -> Result<ProcessorTypesEntity, NifiError>
Retrieves the types of processors that this NiFi supports
Sourcepub async fn get_registry_clients(
&self,
) -> Result<FlowRegistryClientsEntity, NifiError>
pub async fn get_registry_clients( &self, ) -> Result<FlowRegistryClientsEntity, NifiError>
Gets the listing of available flow registry clients
Sourcepub async fn get_remote_process_group_status(
&self,
id: &str,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<RemoteProcessGroupStatusEntity, NifiError>
pub async fn get_remote_process_group_status( &self, id: &str, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<RemoteProcessGroupStatusEntity, NifiError>
Gets status for a remote process group
Sourcepub async fn get_remote_process_group_status_history(
&self,
id: &str,
) -> Result<StatusHistoryEntity, NifiError>
pub async fn get_remote_process_group_status_history( &self, id: &str, ) -> Result<StatusHistoryEntity, NifiError>
Gets the status history
Sourcepub async fn get_reporting_task_definition(
&self,
group: &str,
artifact: &str,
version: &str,
type: &str,
) -> Result<ReportingTaskDefinition, NifiError>
pub async fn get_reporting_task_definition( &self, group: &str, artifact: &str, version: &str, type: &str, ) -> Result<ReportingTaskDefinition, NifiError>
Retrieves the Reporting Task Definition for the specified component type.
Sourcepub async fn get_reporting_task_snapshot(
&self,
reporting_task_id: Option<&str>,
) -> Result<VersionedReportingTaskSnapshot, NifiError>
pub async fn get_reporting_task_snapshot( &self, reporting_task_id: Option<&str>, ) -> Result<VersionedReportingTaskSnapshot, NifiError>
Get a snapshot of the given reporting tasks and any controller services they use
Sourcepub async fn get_reporting_task_types(
&self,
bundle_group_filter: Option<&str>,
bundle_artifact_filter: Option<&str>,
type: Option<&str>,
) -> Result<ReportingTaskTypesEntity, NifiError>
pub async fn get_reporting_task_types( &self, bundle_group_filter: Option<&str>, bundle_artifact_filter: Option<&str>, type: Option<&str>, ) -> Result<ReportingTaskTypesEntity, NifiError>
Retrieves the types of reporting tasks that this NiFi supports
Sourcepub async fn get_reporting_tasks(
&self,
) -> Result<ReportingTasksEntity, NifiError>
pub async fn get_reporting_tasks( &self, ) -> Result<ReportingTasksEntity, NifiError>
Gets all reporting tasks
Sourcepub async fn get_runtime_manifest(&self) -> Result<RuntimeManifest, NifiError>
pub async fn get_runtime_manifest(&self) -> Result<RuntimeManifest, NifiError>
Retrieves the runtime manifest for this NiFi instance.
Sourcepub async fn get_version_differences(
&self,
id: &str,
registry_id: &str,
branch_id_a: &str,
bucket_id_a: &str,
flow_id_a: &str,
version_a: &str,
branch_id_b: &str,
bucket_id_b: &str,
flow_id_b: &str,
version_b: &str,
offset: Option<i32>,
limit: Option<i32>,
) -> Result<FlowComparisonEntity, NifiError>
pub async fn get_version_differences( &self, id: &str, registry_id: &str, branch_id_a: &str, bucket_id_a: &str, flow_id_a: &str, version_a: &str, branch_id_b: &str, bucket_id_b: &str, flow_id_b: &str, version_b: &str, offset: Option<i32>, limit: Option<i32>, ) -> Result<FlowComparisonEntity, NifiError>
Gets the differences between two versions of the same versioned flow, the basis of the comparison will be the first version
Sourcepub async fn get_versions(
&self,
id: &str,
registry_id: &str,
bucket_id: &str,
flow_id: &str,
branch: Option<&str>,
) -> Result<VersionedFlowSnapshotMetadataSetEntity, NifiError>
pub async fn get_versions( &self, id: &str, registry_id: &str, bucket_id: &str, flow_id: &str, branch: Option<&str>, ) -> Result<VersionedFlowSnapshotMetadataSetEntity, NifiError>
Gets the flow versions from the specified registry and bucket for the specified flow for the current user
Sourcepub async fn query_history(
&self,
offset: &str,
count: &str,
sort_column: Option<&str>,
sort_order: Option<&str>,
start_date: Option<&str>,
end_date: Option<&str>,
user_identity: Option<&str>,
source_id: Option<&str>,
) -> Result<HistoryDto, NifiError>
pub async fn query_history( &self, offset: &str, count: &str, sort_column: Option<&str>, sort_order: Option<&str>, start_date: Option<&str>, end_date: Option<&str>, user_identity: Option<&str>, source_id: Option<&str>, ) -> Result<HistoryDto, NifiError>
Gets configuration history
Sourcepub async fn schedule_components(
&self,
id: &str,
body: &Value,
) -> Result<ScheduleComponentsEntity, NifiError>
pub async fn schedule_components( &self, id: &str, body: &Value, ) -> Result<ScheduleComponentsEntity, NifiError>
Schedule or unschedule components in the specified Process Group.
Sourcepub async fn search_cluster(
&self,
q: &str,
) -> Result<ClusterSearchResultsEntity, NifiError>
pub async fn search_cluster( &self, q: &str, ) -> Result<ClusterSearchResultsEntity, NifiError>
Searches the cluster for a node with the specified address
Sourcepub async fn search_flow(
&self,
q: Option<&str>,
a: Option<&str>,
) -> Result<SearchResultsDto, NifiError>
pub async fn search_flow( &self, q: Option<&str>, a: Option<&str>, ) -> Result<SearchResultsDto, NifiError>
Performs a search against this NiFi using the specified search term