pub struct ControllerServicesApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ControllerServicesApi<'a>
impl<'a> ControllerServicesApi<'a>
Sourcepub async fn remove_controller_service(
&self,
id: &str,
version: Option<&str>,
client_id: Option<&str>,
disconnected_node_acknowledged: Option<bool>,
) -> Result<ControllerServiceEntity, NifiError>
pub async fn remove_controller_service( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<ControllerServiceEntity, NifiError>
Deletes a controller service
Calls DELETE /nifi-api/controller-services/{id}.
Parameters
id: The controller service id.version: The revision is used to verify the client is working with the latest version of the flow.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controller-services/{uuid}Write - Parent Process Group if scoped by Process Group - /process-groups/{uuid}Write - Controller if scoped by Controller - /controllerRead - any referenced Controller Services - /controller-services/{uuid}
Sourcepub async fn get_controller_service(
&self,
id: &str,
ui_only: Option<bool>,
) -> Result<ControllerServiceEntity, NifiError>
pub async fn get_controller_service( &self, id: &str, ui_only: Option<bool>, ) -> Result<ControllerServiceEntity, NifiError>
Gets a controller service
If the uiOnly query parameter is provided with a value of true, the returned entity may only contain fields that are necessary for rendering the NiFi User Interface. As such, the selected fields may change at any time, even during incremental releases, without warning. As a result, this parameter should not be provided by any client other than the UI.
Calls GET /nifi-api/controller-services/{id}.
Parameters
id: The controller service id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller-services/{uuid}.
Sourcepub async fn update_controller_service(
&self,
id: &str,
body: &ControllerServiceEntity,
) -> Result<ControllerServiceEntity, NifiError>
pub async fn update_controller_service( &self, id: &str, body: &ControllerServiceEntity, ) -> Result<ControllerServiceEntity, NifiError>
Updates a controller service
Calls PUT /nifi-api/controller-services/{id}.
Parameters
id: The controller service id.body: The controller service configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controller-services/{uuid}Read - any referenced Controller Services if this request changes the reference - /controller-services/{uuid}
Sourcepub fn bulletins<'b>(
&'b self,
id: &'b str,
) -> ControllerServicesBulletinsApi<'b>
pub fn bulletins<'b>( &'b self, id: &'b str, ) -> ControllerServicesBulletinsApi<'b>
Scope operations to the bulletins sub-resource of a specific process group.
id: The controller service id.
Sourcepub fn config<'b>(&'b self, id: &'b str) -> ControllerServicesConfigApi<'b>
pub fn config<'b>(&'b self, id: &'b str) -> ControllerServicesConfigApi<'b>
Scope operations to the config sub-resource of a specific process group.
id: The controller service id.
Sourcepub fn descriptors<'b>(
&'b self,
id: &'b str,
) -> ControllerServicesDescriptorsApi<'b>
pub fn descriptors<'b>( &'b self, id: &'b str, ) -> ControllerServicesDescriptorsApi<'b>
Scope operations to the descriptors sub-resource of a specific process group.
id: The controller service id.
Sourcepub fn references<'b>(
&'b self,
id: &'b str,
) -> ControllerServicesReferencesApi<'b>
pub fn references<'b>( &'b self, id: &'b str, ) -> ControllerServicesReferencesApi<'b>
Scope operations to the references sub-resource of a specific process group.
id: The controller service id.
Sourcepub fn run_status<'b>(
&'b self,
id: &'b str,
) -> ControllerServicesRunStatusApi<'b>
pub fn run_status<'b>( &'b self, id: &'b str, ) -> ControllerServicesRunStatusApi<'b>
Scope operations to the run_status sub-resource of a specific process group.
id: The controller service id.
Sourcepub fn state<'b>(&'b self, id: &'b str) -> ControllerServicesStateApi<'b>
pub fn state<'b>(&'b self, id: &'b str) -> ControllerServicesStateApi<'b>
Scope operations to the state sub-resource of a specific process group.
id: The controller service id.