pub struct FlowStatusApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> FlowStatusApi<'a>
impl<'a> FlowStatusApi<'a>
Sourcepub async fn get_connection_status(
&self,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<ConnectionStatusEntity, NifiError>
pub async fn get_connection_status( &self, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<ConnectionStatusEntity, NifiError>
Gets status for a connection
Calls GET /nifi-api/flow/connections/{id}/status.
Parameters
nodewise: Whether or not to include the breakdown per node. Optional, defaults to falsecluster_node_id: The id of the node where to get the status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.
Sourcepub async fn get_connection_status_history(
&self,
) -> Result<StatusHistoryEntity, NifiError>
pub async fn get_connection_status_history( &self, ) -> Result<StatusHistoryEntity, NifiError>
Gets the status history for a connection
Calls GET /nifi-api/flow/connections/{id}/status/history.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.
Sourcepub async fn get_input_port_status(
&self,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<PortStatusEntity, NifiError>
pub async fn get_input_port_status( &self, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<PortStatusEntity, NifiError>
Gets status for an input port
Calls GET /nifi-api/flow/input-ports/{id}/status.
Parameters
nodewise: Whether or not to include the breakdown per node. Optional, defaults to falsecluster_node_id: The id of the node where to get the status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.
Sourcepub async fn get_output_port_status(
&self,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<PortStatusEntity, NifiError>
pub async fn get_output_port_status( &self, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<PortStatusEntity, NifiError>
Gets status for an output port
Calls GET /nifi-api/flow/output-ports/{id}/status.
Parameters
nodewise: Whether or not to include the breakdown per node. Optional, defaults to falsecluster_node_id: The id of the node where to get the status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.
Sourcepub async fn get_process_group_status(
&self,
recursive: Option<bool>,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<ProcessGroupStatusEntity, NifiError>
pub async fn get_process_group_status( &self, recursive: Option<bool>, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<ProcessGroupStatusEntity, NifiError>
Gets the status for a process group
The status for a process group includes status for all descendent components. When invoked on the root group with recursive set to true, it will return the current status of every component in the flow.
Calls GET /nifi-api/flow/process-groups/{id}/status.
Parameters
recursive: Whether all descendant groups and the status of their content will be included. Optional, defaults to falsenodewise: Whether or not to include the breakdown per node. Optional, defaults to falsecluster_node_id: The id of the node where to get the status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.
Sourcepub async fn get_process_group_status_history(
&self,
) -> Result<StatusHistoryEntity, NifiError>
pub async fn get_process_group_status_history( &self, ) -> Result<StatusHistoryEntity, NifiError>
Gets status history for a remote process group
Calls GET /nifi-api/flow/process-groups/{id}/status/history.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.
Sourcepub async fn get_processor_status(
&self,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<ProcessorStatusEntity, NifiError>
pub async fn get_processor_status( &self, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<ProcessorStatusEntity, NifiError>
Gets status for a processor
Calls GET /nifi-api/flow/processors/{id}/status.
Parameters
nodewise: Whether or not to include the breakdown per node. Optional, defaults to falsecluster_node_id: The id of the node where to get the status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.
Sourcepub async fn get_processor_status_history(
&self,
) -> Result<StatusHistoryEntity, NifiError>
pub async fn get_processor_status_history( &self, ) -> Result<StatusHistoryEntity, NifiError>
Gets status history for a processor
Calls GET /nifi-api/flow/processors/{id}/status/history.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.
Sourcepub async fn get_remote_process_group_status(
&self,
nodewise: Option<bool>,
cluster_node_id: Option<&str>,
) -> Result<RemoteProcessGroupStatusEntity, NifiError>
pub async fn get_remote_process_group_status( &self, nodewise: Option<bool>, cluster_node_id: Option<&str>, ) -> Result<RemoteProcessGroupStatusEntity, NifiError>
Gets status for a remote process group
Calls GET /nifi-api/flow/remote-process-groups/{id}/status.
Parameters
nodewise: Whether or not to include the breakdown per node. Optional, defaults to falsecluster_node_id: The id of the node where to get the status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.
Sourcepub async fn get_remote_process_group_status_history(
&self,
) -> Result<StatusHistoryEntity, NifiError>
pub async fn get_remote_process_group_status_history( &self, ) -> Result<StatusHistoryEntity, NifiError>
Gets the status history
Calls GET /nifi-api/flow/remote-process-groups/{id}/status/history.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.