pub struct ControllerApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ControllerApi<'a>
impl<'a> ControllerApi<'a>
Sourcepub async fn create_bulletin(
&self,
body: &BulletinEntity,
) -> Result<BulletinEntity, NifiError>
pub async fn create_bulletin( &self, body: &BulletinEntity, ) -> Result<BulletinEntity, NifiError>
Creates a new bulletin
Calls POST /nifi-api/controller/bulletin.
Parameters
body: The reporting task configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_cluster(&self) -> Result<ClusterDto, NifiError>
pub async fn get_cluster(&self) -> Result<ClusterDto, NifiError>
Gets the contents of the cluster
Returns the contents of the cluster including all nodes and their status.
Calls GET /nifi-api/controller/cluster.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn delete_node(&self, id: &str) -> Result<NodeDto, NifiError>
pub async fn delete_node(&self, id: &str) -> Result<NodeDto, NifiError>
Removes a node from the cluster
Calls DELETE /nifi-api/controller/cluster/nodes/{id}.
Parameters
id: The node id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_node(&self, id: &str) -> Result<NodeDto, NifiError>
pub async fn get_node(&self, id: &str) -> Result<NodeDto, NifiError>
Gets a node in the cluster
Calls GET /nifi-api/controller/cluster/nodes/{id}.
Parameters
id: The node id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn update_node(
&self,
id: &str,
body: &NodeEntity,
) -> Result<NodeDto, NifiError>
pub async fn update_node( &self, id: &str, body: &NodeEntity, ) -> Result<NodeDto, NifiError>
Updates a node in the cluster
Calls PUT /nifi-api/controller/cluster/nodes/{id}.
Parameters
id: The node id.body: The node configuration. The only configuration that will be honored at this endpoint is the status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_controller_config(
&self,
) -> Result<ControllerConfigurationEntity, NifiError>
pub async fn get_controller_config( &self, ) -> Result<ControllerConfigurationEntity, NifiError>
Retrieves the configuration for this NiFi Controller
Calls GET /nifi-api/controller/config.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn update_controller_config(
&self,
body: &ControllerConfigurationEntity,
) -> Result<ControllerConfigurationEntity, NifiError>
pub async fn update_controller_config( &self, body: &ControllerConfigurationEntity, ) -> Result<ControllerConfigurationEntity, NifiError>
Retrieves the configuration for this NiFi
Calls PUT /nifi-api/controller/config.
Parameters
body: The controller configuration.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn create_controller_service(
&self,
body: &ControllerServiceEntity,
) -> Result<ControllerServiceEntity, NifiError>
pub async fn create_controller_service( &self, body: &ControllerServiceEntity, ) -> Result<ControllerServiceEntity, NifiError>
Creates a new controller service
Calls POST /nifi-api/controller/controller-services.
Parameters
body: The controller service configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controllerRead - any referenced Controller Services - /controller-services/{uuid}Write - if the Controller Service is restricted - /restricted-components
Sourcepub async fn get_flow_analysis_rules(
&self,
) -> Result<FlowAnalysisRulesEntity, NifiError>
pub async fn get_flow_analysis_rules( &self, ) -> Result<FlowAnalysisRulesEntity, NifiError>
Gets all flow analysis rules
Calls GET /nifi-api/controller/flow-analysis-rules.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.
Sourcepub async fn create_flow_analysis_rule(
&self,
body: &FlowAnalysisRuleEntity,
) -> Result<FlowAnalysisRuleEntity, NifiError>
pub async fn create_flow_analysis_rule( &self, body: &FlowAnalysisRuleEntity, ) -> Result<FlowAnalysisRuleEntity, NifiError>
Creates a new flow analysis rule
Calls POST /nifi-api/controller/flow-analysis-rules.
Parameters
body: The flow analysis rule configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controllerRead - any referenced Controller Services - /controller-services/{uuid}Write - if the Flow Analysis Rule is restricted - /restricted-components
Sourcepub async fn remove_flow_analysis_rule(
&self,
id: &str,
version: Option<&str>,
client_id: Option<&str>,
disconnected_node_acknowledged: Option<bool>,
) -> Result<FlowAnalysisRuleEntity, NifiError>
pub async fn remove_flow_analysis_rule( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<FlowAnalysisRuleEntity, NifiError>
Deletes a flow analysis rule
Calls DELETE /nifi-api/controller/flow-analysis-rules/{id}.
Parameters
id: The flow analysis rule id.version: The revision is used to verify the client is working with the latest version of the flow.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /flow-analysis-rules/{uuid}Write - /controllerRead - any referenced Controller Services - /controller-services/{uuid}
Sourcepub async fn get_flow_analysis_rule(
&self,
id: &str,
) -> Result<FlowAnalysisRuleEntity, NifiError>
pub async fn get_flow_analysis_rule( &self, id: &str, ) -> Result<FlowAnalysisRuleEntity, NifiError>
Gets a flow analysis rule
Calls GET /nifi-api/controller/flow-analysis-rules/{id}.
Parameters
id: The flow analysis rule id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow-analysis-rules/{uuid}.
Sourcepub async fn update_flow_analysis_rule(
&self,
id: &str,
body: &FlowAnalysisRuleEntity,
) -> Result<FlowAnalysisRuleEntity, NifiError>
pub async fn update_flow_analysis_rule( &self, id: &str, body: &FlowAnalysisRuleEntity, ) -> Result<FlowAnalysisRuleEntity, NifiError>
Updates a flow analysis rule
Calls PUT /nifi-api/controller/flow-analysis-rules/{id}.
Parameters
id: The flow analysis rule id.body: The flow analysis rule configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /flow-analysis-rules/{uuid}Read - any referenced Controller Services if this request changes the reference - /controller-services/{uuid}
Sourcepub async fn delete_history(
&self,
end_date: &str,
) -> Result<HistoryDto, NifiError>
pub async fn delete_history( &self, end_date: &str, ) -> Result<HistoryDto, NifiError>
Purges history
Calls DELETE /nifi-api/controller/history.
Parameters
end_date: Purge actions before this date/time.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_nar_summaries(&self) -> Result<NarSummariesEntity, NifiError>
pub async fn get_nar_summaries(&self) -> Result<NarSummariesEntity, NifiError>
Retrieves summary information for installed NARs
Calls GET /nifi-api/controller/nar-manager/nars.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn upload_nar(
&self,
filename: Option<&str>,
data: Vec<u8>,
) -> Result<NarSummaryDto, NifiError>
pub async fn upload_nar( &self, filename: Option<&str>, data: Vec<u8>, ) -> Result<NarSummaryDto, NifiError>
Uploads a NAR and requests for it to be installed
Calls POST /nifi-api/controller/nar-manager/nars/content.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn delete_nar(
&self,
id: &str,
disconnected_node_acknowledged: Option<bool>,
force: Option<bool>,
) -> Result<NarSummaryDto, NifiError>
pub async fn delete_nar( &self, id: &str, disconnected_node_acknowledged: Option<bool>, force: Option<bool>, ) -> Result<NarSummaryDto, NifiError>
Deletes an installed NAR
Calls DELETE /nifi-api/controller/nar-manager/nars/{id}.
Parameters
id: The id of the NAR.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_nar_summary(
&self,
id: &str,
) -> Result<NarDetailsEntity, NifiError>
pub async fn get_nar_summary( &self, id: &str, ) -> Result<NarDetailsEntity, NifiError>
Retrieves the summary information for the NAR with the given identifier
Calls GET /nifi-api/controller/nar-manager/nars/{id}.
Parameters
id: The id of the NAR.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn create_parameter_provider(
&self,
body: &ParameterProviderEntity,
) -> Result<ParameterProviderEntity, NifiError>
pub async fn create_parameter_provider( &self, body: &ParameterProviderEntity, ) -> Result<ParameterProviderEntity, NifiError>
Creates a new parameter provider
Calls POST /nifi-api/controller/parameter-providers.
Parameters
body: The parameter provider configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controllerRead - any referenced Controller Services - /controller-services/{uuid}Write - if the Parameter Provider is restricted - /restricted-components
Sourcepub async fn get_flow_registry_clients(
&self,
) -> Result<FlowRegistryClientsEntity, NifiError>
pub async fn get_flow_registry_clients( &self, ) -> Result<FlowRegistryClientsEntity, NifiError>
Gets the listing of available flow registry clients
Calls GET /nifi-api/controller/registry-clients.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn create_flow_registry_client(
&self,
body: &FlowRegistryClientEntity,
) -> Result<FlowRegistryClientEntity, NifiError>
pub async fn create_flow_registry_client( &self, body: &FlowRegistryClientEntity, ) -> Result<FlowRegistryClientEntity, NifiError>
Creates a new flow registry client
Calls POST /nifi-api/controller/registry-clients.
Parameters
body: The flow registry client configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Read - /controllerWrite - /controller
Sourcepub async fn delete_flow_registry_client(
&self,
id: &str,
version: Option<&str>,
client_id: Option<&str>,
disconnected_node_acknowledged: Option<bool>,
) -> Result<FlowRegistryClientEntity, NifiError>
pub async fn delete_flow_registry_client( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<FlowRegistryClientEntity, NifiError>
Deletes a flow registry client
Calls DELETE /nifi-api/controller/registry-clients/{id}.
Parameters
id: The flow registry client id.version: The revision is used to verify the client is working with the latest version of the flow.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller/registry-clients/{id}.
Sourcepub async fn get_flow_registry_client(
&self,
id: &str,
) -> Result<FlowRegistryClientEntity, NifiError>
pub async fn get_flow_registry_client( &self, id: &str, ) -> Result<FlowRegistryClientEntity, NifiError>
Gets a flow registry client
Calls GET /nifi-api/controller/registry-clients/{id}.
Parameters
id: The flow registry client id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller/registry-clients/{id}.
Sourcepub async fn update_flow_registry_client(
&self,
id: &str,
body: &FlowRegistryClientEntity,
) -> Result<FlowRegistryClientEntity, NifiError>
pub async fn update_flow_registry_client( &self, id: &str, body: &FlowRegistryClientEntity, ) -> Result<FlowRegistryClientEntity, NifiError>
Updates a flow registry client
Calls PUT /nifi-api/controller/registry-clients/{id}.
Parameters
id: The flow registry client id.body: The flow registry client configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller/registry-clients/{id}.
Sourcepub async fn get_registry_client_types(
&self,
) -> Result<FlowRegistryClientTypesEntity, NifiError>
pub async fn get_registry_client_types( &self, ) -> Result<FlowRegistryClientTypesEntity, NifiError>
Retrieves the types of flow that this NiFi supports
Note: This endpoint is subject to change as NiFi and it’s REST API evolve.
Calls GET /nifi-api/controller/registry-types.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn create_reporting_task(
&self,
body: &ReportingTaskEntity,
) -> Result<ReportingTaskEntity, NifiError>
pub async fn create_reporting_task( &self, body: &ReportingTaskEntity, ) -> Result<ReportingTaskEntity, NifiError>
Creates a new reporting task
Calls POST /nifi-api/controller/reporting-tasks.
Parameters
body: The reporting task configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controllerRead - any referenced Controller Services - /controller-services/{uuid}Write - if the Reporting Task is restricted - /restricted-components
Sourcepub async fn import_reporting_task_snapshot(
&self,
body: &VersionedReportingTaskImportRequestEntity,
) -> Result<VersionedReportingTaskImportResponseEntity, NifiError>
pub async fn import_reporting_task_snapshot( &self, body: &VersionedReportingTaskImportRequestEntity, ) -> Result<VersionedReportingTaskImportResponseEntity, NifiError>
Imports a reporting task snapshot
Calls POST /nifi-api/controller/reporting-tasks/import.
Parameters
body: The import request containing the reporting task snapshot to import.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_node_status_history(
&self,
) -> Result<ComponentHistoryDto, NifiError>
pub async fn get_node_status_history( &self, ) -> Result<ComponentHistoryDto, NifiError>
Gets status history for the node
Note: This endpoint is subject to change as NiFi and it’s REST API evolve.
Calls GET /nifi-api/controller/status/history.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub fn bulletins<'b>(&'b self, id: &'b str) -> ControllerBulletinsApi<'b>
pub fn bulletins<'b>(&'b self, id: &'b str) -> ControllerBulletinsApi<'b>
Scope operations to the bulletins sub-resource of a specific process group.
id: The flow analysis rule id.
Sourcepub fn config<'b>(&'b self, id: &'b str) -> ControllerConfigApi<'b>
pub fn config<'b>(&'b self, id: &'b str) -> ControllerConfigApi<'b>
Scope operations to the config sub-resource of a specific process group.
id: The flow analysis rules id.
Sourcepub fn content<'b>(&'b self, id: &'b str) -> ControllerContentApi<'b>
pub fn content<'b>(&'b self, id: &'b str) -> ControllerContentApi<'b>
Scope operations to the content sub-resource of a specific process group.
id: The id of the NAR.
Sourcepub fn descriptors<'b>(&'b self, id: &'b str) -> ControllerDescriptorsApi<'b>
pub fn descriptors<'b>(&'b self, id: &'b str) -> ControllerDescriptorsApi<'b>
Scope operations to the descriptors sub-resource of a specific process group.
id: The flow analysis rule id.
Sourcepub fn details<'b>(&'b self, id: &'b str) -> ControllerDetailsApi<'b>
pub fn details<'b>(&'b self, id: &'b str) -> ControllerDetailsApi<'b>
Scope operations to the details sub-resource of a specific process group.
id: The id of the NAR.
Sourcepub fn run_status<'b>(&'b self, id: &'b str) -> ControllerRunStatusApi<'b>
pub fn run_status<'b>(&'b self, id: &'b str) -> ControllerRunStatusApi<'b>
Scope operations to the run_status sub-resource of a specific process group.
id: The flow analysis rule id.
Sourcepub fn state<'b>(&'b self, id: &'b str) -> ControllerStateApi<'b>
pub fn state<'b>(&'b self, id: &'b str) -> ControllerStateApi<'b>
Scope operations to the state sub-resource of a specific process group.
id: The flow analysis rule id.