pub struct ProcessGroupsFlowContentsApi<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProcessGroupsFlowContentsApi<'a>
impl<'a> ProcessGroupsFlowContentsApi<'a>
Sourcepub async fn replace_process_group(
&self,
body: &ProcessGroupImportEntity,
) -> Result<ProcessGroupImportEntity, NifiError>
pub async fn replace_process_group( &self, body: &ProcessGroupImportEntity, ) -> Result<ProcessGroupImportEntity, NifiError>
Replace Process Group contents with the given ID with the specified Process Group contents
This endpoint is used for replication within a cluster, when replacing a flow with a new flow. It expects that the flow beingreplaced is not under version control and that the given snapshot will not modify any Processor that is currently running or any Controller Service that is enabled. Note: This endpoint is subject to change as NiFi and it’s REST API evolve.
Calls PUT /nifi-api/process-groups/{id}/flow-contents.
Parameters
body: The process group replace request entity.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Read - /process-groups/{uuid}Write - /process-groups/{uuid}