pub struct Controller<'a> { /* private fields */ }Implementations
Sourceimpl<'a> Controller<'a>
impl<'a> Controller<'a>
Sourcepub async fn create_bulletin(
&self,
body: &BulletinEntity,
) -> Result<BulletinEntity, NifiError>
pub async fn create_bulletin( &self, body: &BulletinEntity, ) -> Result<BulletinEntity, NifiError>
Creates a new bulletin
Calls POST /nifi-api/controller/bulletin.
Parameters
body: The reporting task configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_cluster(&self) -> Result<ClusterDto, NifiError>
pub async fn get_cluster(&self) -> Result<ClusterDto, NifiError>
Gets the contents of the cluster
Returns the contents of the cluster including all nodes and their status.
Calls GET /nifi-api/controller/cluster.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn delete_node(&self, id: &str) -> Result<NodeDto, NifiError>
pub async fn delete_node(&self, id: &str) -> Result<NodeDto, NifiError>
Removes a node from the cluster
Calls DELETE /nifi-api/controller/cluster/nodes/{id}.
Parameters
id: The node id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_node(&self, id: &str) -> Result<NodeDto, NifiError>
pub async fn get_node(&self, id: &str) -> Result<NodeDto, NifiError>
Gets a node in the cluster
Calls GET /nifi-api/controller/cluster/nodes/{id}.
Parameters
id: The node id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn update_node(
&self,
id: &str,
body: &NodeEntity,
) -> Result<NodeDto, NifiError>
pub async fn update_node( &self, id: &str, body: &NodeEntity, ) -> Result<NodeDto, NifiError>
Updates a node in the cluster
Calls PUT /nifi-api/controller/cluster/nodes/{id}.
Parameters
id: The node id.body: The node configuration. The only configuration that will be honored at this endpoint is the status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_controller_config(
&self,
) -> Result<ControllerConfigurationEntity, NifiError>
pub async fn get_controller_config( &self, ) -> Result<ControllerConfigurationEntity, NifiError>
Retrieves the configuration for this NiFi Controller
Calls GET /nifi-api/controller/config.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn update_controller_config(
&self,
body: &ControllerConfigurationEntity,
) -> Result<ControllerConfigurationEntity, NifiError>
pub async fn update_controller_config( &self, body: &ControllerConfigurationEntity, ) -> Result<ControllerConfigurationEntity, NifiError>
Updates the configuration for this NiFi
Calls PUT /nifi-api/controller/config.
Parameters
body: The controller configuration.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn create_controller_service(
&self,
body: &ControllerServiceEntity,
) -> Result<ControllerServiceEntity, NifiError>
pub async fn create_controller_service( &self, body: &ControllerServiceEntity, ) -> Result<ControllerServiceEntity, NifiError>
Creates a new controller service
Calls POST /nifi-api/controller/controller-services.
Parameters
body: The controller service configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controllerRead - any referenced Controller Services - /controller-services/{uuid}Write - if the Controller Service is restricted - /restricted-components
Sourcepub async fn get_flow_analysis_rules(
&self,
) -> Result<FlowAnalysisRulesEntity, NifiError>
pub async fn get_flow_analysis_rules( &self, ) -> Result<FlowAnalysisRulesEntity, NifiError>
Gets all flow analysis rules
Calls GET /nifi-api/controller/flow-analysis-rules.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow.
Sourcepub async fn create_flow_analysis_rule(
&self,
body: &FlowAnalysisRuleEntity,
) -> Result<FlowAnalysisRuleEntity, NifiError>
pub async fn create_flow_analysis_rule( &self, body: &FlowAnalysisRuleEntity, ) -> Result<FlowAnalysisRuleEntity, NifiError>
Creates a new flow analysis rule
Calls POST /nifi-api/controller/flow-analysis-rules.
Parameters
body: The flow analysis rule configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controllerRead - any referenced Controller Services - /controller-services/{uuid}Write - if the Flow Analysis Rule is restricted - /restricted-components
Sourcepub async fn remove_flow_analysis_rule(
&self,
id: &str,
version: Option<&str>,
client_id: Option<&str>,
disconnected_node_acknowledged: Option<bool>,
) -> Result<FlowAnalysisRuleEntity, NifiError>
pub async fn remove_flow_analysis_rule( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<FlowAnalysisRuleEntity, NifiError>
Deletes a flow analysis rule
Calls DELETE /nifi-api/controller/flow-analysis-rules/{id}.
Parameters
id: The flow analysis rule id.version: The revision is used to verify the client is working with the latest version of the flow.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /flow-analysis-rules/{uuid}Write - /controllerRead - any referenced Controller Services - /controller-services/{uuid}
Sourcepub async fn get_flow_analysis_rule(
&self,
id: &str,
) -> Result<FlowAnalysisRuleEntity, NifiError>
pub async fn get_flow_analysis_rule( &self, id: &str, ) -> Result<FlowAnalysisRuleEntity, NifiError>
Gets a flow analysis rule
Calls GET /nifi-api/controller/flow-analysis-rules/{id}.
Parameters
id: The flow analysis rule id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow-analysis-rules/{uuid}.
Sourcepub async fn update_flow_analysis_rule(
&self,
id: &str,
body: &FlowAnalysisRuleEntity,
) -> Result<FlowAnalysisRuleEntity, NifiError>
pub async fn update_flow_analysis_rule( &self, id: &str, body: &FlowAnalysisRuleEntity, ) -> Result<FlowAnalysisRuleEntity, NifiError>
Updates a flow analysis rule
Calls PUT /nifi-api/controller/flow-analysis-rules/{id}.
Parameters
id: The flow analysis rule id.body: The flow analysis rule configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /flow-analysis-rules/{uuid}Read - any referenced Controller Services if this request changes the reference - /controller-services/{uuid}
Sourcepub async fn delete_history(
&self,
end_date: &str,
) -> Result<HistoryDto, NifiError>
pub async fn delete_history( &self, end_date: &str, ) -> Result<HistoryDto, NifiError>
Purges history
Calls DELETE /nifi-api/controller/history.
Parameters
end_date: Purge actions before this date/time.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_nar_summaries(&self) -> Result<NarSummariesEntity, NifiError>
pub async fn get_nar_summaries(&self) -> Result<NarSummariesEntity, NifiError>
Retrieves summary information for installed NARs
Calls GET /nifi-api/controller/nar-manager/nars.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn upload_nar(
&self,
filename: Option<&str>,
data: Vec<u8>,
) -> Result<NarSummaryDto, NifiError>
pub async fn upload_nar( &self, filename: Option<&str>, data: Vec<u8>, ) -> Result<NarSummaryDto, NifiError>
Uploads a NAR and requests for it to be installed
Calls POST /nifi-api/controller/nar-manager/nars/content.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn delete_nar(
&self,
id: &str,
disconnected_node_acknowledged: Option<bool>,
force: Option<bool>,
) -> Result<NarSummaryDto, NifiError>
pub async fn delete_nar( &self, id: &str, disconnected_node_acknowledged: Option<bool>, force: Option<bool>, ) -> Result<NarSummaryDto, NifiError>
Deletes an installed NAR
Calls DELETE /nifi-api/controller/nar-manager/nars/{id}.
Parameters
id: The id of the NAR.disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.force: Indicates if the NAR should be deleted even when components are instantiated.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_nar_summary(
&self,
id: &str,
) -> Result<NarDetailsEntity, NifiError>
pub async fn get_nar_summary( &self, id: &str, ) -> Result<NarDetailsEntity, NifiError>
Retrieves the summary information for the NAR with the given identifier
Calls GET /nifi-api/controller/nar-manager/nars/{id}.
Parameters
id: The id of the NAR.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn create_parameter_provider(
&self,
body: &ParameterProviderEntity,
) -> Result<ParameterProviderEntity, NifiError>
pub async fn create_parameter_provider( &self, body: &ParameterProviderEntity, ) -> Result<ParameterProviderEntity, NifiError>
Creates a new parameter provider
Calls POST /nifi-api/controller/parameter-providers.
Parameters
body: The parameter provider configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controllerRead - any referenced Controller Services - /controller-services/{uuid}Write - if the Parameter Provider is restricted - /restricted-components
Sourcepub async fn get_flow_registry_clients(
&self,
) -> Result<FlowRegistryClientsEntity, NifiError>
pub async fn get_flow_registry_clients( &self, ) -> Result<FlowRegistryClientsEntity, NifiError>
Gets the listing of available flow registry clients
Calls GET /nifi-api/controller/registry-clients.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn create_flow_registry_client(
&self,
body: &FlowRegistryClientEntity,
) -> Result<FlowRegistryClientEntity, NifiError>
pub async fn create_flow_registry_client( &self, body: &FlowRegistryClientEntity, ) -> Result<FlowRegistryClientEntity, NifiError>
Creates a new flow registry client
Calls POST /nifi-api/controller/registry-clients.
Parameters
body: The flow registry client configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Read - /controllerWrite - /controller
Sourcepub async fn delete_flow_registry_client(
&self,
id: &str,
version: Option<&str>,
client_id: Option<&str>,
disconnected_node_acknowledged: Option<bool>,
) -> Result<FlowRegistryClientEntity, NifiError>
pub async fn delete_flow_registry_client( &self, id: &str, version: Option<&str>, client_id: Option<&str>, disconnected_node_acknowledged: Option<bool>, ) -> Result<FlowRegistryClientEntity, NifiError>
Deletes a flow registry client
Calls DELETE /nifi-api/controller/registry-clients/{id}.
Parameters
id: The flow registry client id.version: The revision is used to verify the client is working with the latest version of the flow.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.disconnected_node_acknowledged: Acknowledges that this node is disconnected to allow for mutable requests to proceed.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller/registry-clients/{id}.
Sourcepub async fn get_flow_registry_client(
&self,
id: &str,
) -> Result<FlowRegistryClientEntity, NifiError>
pub async fn get_flow_registry_client( &self, id: &str, ) -> Result<FlowRegistryClientEntity, NifiError>
Gets a flow registry client
Calls GET /nifi-api/controller/registry-clients/{id}.
Parameters
id: The flow registry client id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller/registry-clients/{id}.
Sourcepub async fn update_flow_registry_client(
&self,
id: &str,
body: &FlowRegistryClientEntity,
) -> Result<FlowRegistryClientEntity, NifiError>
pub async fn update_flow_registry_client( &self, id: &str, body: &FlowRegistryClientEntity, ) -> Result<FlowRegistryClientEntity, NifiError>
Updates a flow registry client
Calls PUT /nifi-api/controller/registry-clients/{id}.
Parameters
id: The flow registry client id.body: The flow registry client configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller/registry-clients/{id}.
Sourcepub async fn get_registry_client_types(
&self,
) -> Result<FlowRegistryClientTypesEntity, NifiError>
pub async fn get_registry_client_types( &self, ) -> Result<FlowRegistryClientTypesEntity, NifiError>
Retrieves the types of flow registry clients that this NiFi supports
Note: This endpoint is subject to change as NiFi and it’s REST API evolve.
Calls GET /nifi-api/controller/registry-types.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn create_reporting_task(
&self,
body: &ReportingTaskEntity,
) -> Result<ReportingTaskEntity, NifiError>
pub async fn create_reporting_task( &self, body: &ReportingTaskEntity, ) -> Result<ReportingTaskEntity, NifiError>
Creates a new reporting task
Calls POST /nifi-api/controller/reporting-tasks.
Parameters
body: The reporting task configuration details.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Write - /controllerRead - any referenced Controller Services - /controller-services/{uuid}Write - if the Reporting Task is restricted - /restricted-components
Sourcepub async fn import_reporting_task_snapshot(
&self,
body: &VersionedReportingTaskImportRequestEntity,
) -> Result<VersionedReportingTaskImportResponseEntity, NifiError>
pub async fn import_reporting_task_snapshot( &self, body: &VersionedReportingTaskImportRequestEntity, ) -> Result<VersionedReportingTaskImportResponseEntity, NifiError>
Imports a reporting task snapshot
Calls POST /nifi-api/controller/reporting-tasks/import.
Parameters
body: The import request containing the reporting task snapshot to import.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller.
Sourcepub async fn get_node_status_history(
&self,
) -> Result<ComponentHistoryDto, NifiError>
pub async fn get_node_status_history( &self, ) -> Result<ComponentHistoryDto, NifiError>
Gets status history for the node
Note: This endpoint is subject to change as NiFi and it’s REST API evolve.
Calls GET /nifi-api/controller/status/history.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn clear_flow_analysis_rule_bulletins(
&self,
id: &str,
body: &ClearBulletinsRequestEntity,
) -> Result<ClearBulletinsResultEntity, NifiError>
pub async fn clear_flow_analysis_rule_bulletins( &self, id: &str, body: &ClearBulletinsRequestEntity, ) -> Result<ClearBulletinsResultEntity, NifiError>
Clears bulletins for a flow analysis rule
Calls POST /nifi-api/controller/flow-analysis-rules/{id}/bulletins/clear-requests.
Parameters
id: The flow analysis rule id.body: The request to clear bulletins.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /flow-analysis-rules/{uuid}.
Sourcepub async fn clear_parameter_provider_bulletins(
&self,
id: &str,
body: &ClearBulletinsRequestEntity,
) -> Result<ClearBulletinsResultEntity, NifiError>
pub async fn clear_parameter_provider_bulletins( &self, id: &str, body: &ClearBulletinsRequestEntity, ) -> Result<ClearBulletinsResultEntity, NifiError>
Clears bulletins for a parameter provider
Calls POST /nifi-api/controller/parameter-providers/{id}/bulletins/clear-requests.
Parameters
id: The parameter provider id.body: The request to clear bulletins.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /parameter-providers/{uuid}.
Sourcepub async fn clear_registry_client_bulletins(
&self,
id: &str,
body: &ClearBulletinsRequestEntity,
) -> Result<ClearBulletinsResultEntity, NifiError>
pub async fn clear_registry_client_bulletins( &self, id: &str, body: &ClearBulletinsRequestEntity, ) -> Result<ClearBulletinsResultEntity, NifiError>
Clears bulletins for a registry client
Calls POST /nifi-api/controller/registry-clients/{id}/bulletins/clear-requests.
Parameters
id: The registry client id.body: The request to clear bulletins.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /controller/registry-clients/{uuid}.
Sourcepub async fn analyze_flow_analysis_rule_configuration(
&self,
id: &str,
body: &ConfigurationAnalysisEntity,
) -> Result<ConfigurationAnalysisDto, NifiError>
pub async fn analyze_flow_analysis_rule_configuration( &self, id: &str, body: &ConfigurationAnalysisEntity, ) -> Result<ConfigurationAnalysisDto, NifiError>
Performs analysis of the component’s configuration, providing information about which attributes are referenced.
Calls POST /nifi-api/controller/flow-analysis-rules/{id}/config/analysis.
Parameters
id: The flow analysis rules id.body: The configuration analysis request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow-analysis-rules/{uuid}.
Sourcepub async fn submit_flow_analysis_rule_config_verification_request(
&self,
id: &str,
body: &VerifyConfigRequestEntity,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn submit_flow_analysis_rule_config_verification_request( &self, id: &str, body: &VerifyConfigRequestEntity, ) -> Result<VerifyConfigRequestDto, NifiError>
Performs verification of the Flow Analysis Rule’s configuration
This will initiate the process of verifying a given Flow Analysis Rule configuration. This may be a long-running task. As a result, this endpoint will immediately return a FlowAnalysisRuleConfigVerificationRequestEntity, and the process of performing the verification will occur asynchronously in the background. The client may then periodically poll the status of the request by issuing a GET request to /flow-analysis-rules/{taskId}/verification-requests/{requestId}. Once the request is completed, the client is expected to issue a DELETE request to /flow-analysis-rules/{serviceId}/verification-requests/{requestId}.
Calls POST /nifi-api/controller/flow-analysis-rules/{id}/config/verification-requests.
Parameters
id: The flow analysis rules id.body: The flow analysis rules configuration verification request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow-analysis-rules/{uuid}.
Sourcepub async fn delete_flow_analysis_rule_verification_request(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn delete_flow_analysis_rule_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Deletes the Verification Request with the given ID
Deletes the Verification Request with the given ID. After a request is created, it is expected that the client will properly clean up the request by DELETE’ing it, once the Verification process has completed. If the request is deleted before the request completes, then the Verification request will finish the step that it is currently performing and then will cancel any subsequent steps.
Calls DELETE /nifi-api/controller/flow-analysis-rules/{id}/config/verification-requests/{requestId}.
Parameters
id: The ID of the Flow Analysis Rulerequest_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can remove it.
Sourcepub async fn get_flow_analysis_rule_verification_request(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn get_flow_analysis_rule_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Returns the Verification Request with the given ID
Returns the Verification Request with the given ID. Once an Verification Request has been created, that request can subsequently be retrieved via this endpoint, and the request that is fetched will contain the updated state, such as percent complete, the current state of the request, and any failures.
Calls GET /nifi-api/controller/flow-analysis-rules/{id}/config/verification-requests/{requestId}.
Parameters
id: The ID of the Flow Analysis Rulerequest_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can get it.
Sourcepub async fn analyze_flow_registry_client_configuration(
&self,
id: &str,
body: &ConfigurationAnalysisEntity,
) -> Result<ConfigurationAnalysisDto, NifiError>
pub async fn analyze_flow_registry_client_configuration( &self, id: &str, body: &ConfigurationAnalysisEntity, ) -> Result<ConfigurationAnalysisDto, NifiError>
Performs analysis of the component’s configuration, providing information about which attributes are referenced.
Calls POST /nifi-api/controller/registry-clients/{id}/config/analysis.
Parameters
id: The registry client id.body: The configuration analysis request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn submit_registry_client_config_verification_request(
&self,
id: &str,
body: &VerifyConfigRequestEntity,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn submit_registry_client_config_verification_request( &self, id: &str, body: &VerifyConfigRequestEntity, ) -> Result<VerifyConfigRequestDto, NifiError>
Performs verification of the Registry Client’s configuration
Initiates verification of a Registry Client configuration. The request returns immediately with a request entity while verification runs asynchronously. The client should poll /controller/registry-clients/{clientId}/config/verification-requests/{requestId} for status and DELETE the request once verification completes.
Calls POST /nifi-api/controller/registry-clients/{id}/config/verification-requests.
Parameters
id: The registry client id.body: The registry client configuration verification request.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn delete_registry_client_verification_request(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn delete_registry_client_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Deletes the Verification Request with the given ID
Deletes the Verification Request with the given ID. After a request is created, it is expected that the client will properly clean up the request by DELETE’ing it, once the Verification process has completed. If the request is deleted before the request completes, then the Verification request will finish the step that it is currently performing and then will cancel any subsequent steps.
Calls DELETE /nifi-api/controller/registry-clients/{id}/config/verification-requests/{requestId}.
Parameters
id: The ID of the Registry Clientrequest_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can remove it.
Sourcepub async fn get_registry_client_verification_request(
&self,
id: &str,
request_id: &str,
) -> Result<VerifyConfigRequestDto, NifiError>
pub async fn get_registry_client_verification_request( &self, id: &str, request_id: &str, ) -> Result<VerifyConfigRequestDto, NifiError>
Returns the Verification Request with the given ID
Returns the Verification Request with the given ID. Once a Verification Request has been created, that request can subsequently be retrieved via this endpoint, and the request that is fetched will contain the updated state, such as percent complete, the current state of the request, and any failures.
Calls GET /nifi-api/controller/registry-clients/{id}/config/verification-requests/{requestId}.
Parameters
id: The ID of the Registry Clientrequest_id: The ID of the Verification Request
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Only the user that submitted the request can get it.
Sourcepub async fn download_nar(&self, id: &str) -> Result<Vec<u8>, NifiError>
pub async fn download_nar(&self, id: &str) -> Result<Vec<u8>, NifiError>
Retrieves the content of the NAR with the given id
Calls GET /nifi-api/controller/nar-manager/nars/{id}/content.
Parameters
id: The id of the NAR.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn download_nar_stream(
&self,
id: &str,
) -> Result<BytesStream, NifiError>
pub async fn download_nar_stream( &self, id: &str, ) -> Result<BytesStream, NifiError>
Streaming variant: yields body chunks as they arrive instead of buffering the whole response.
Retrieves the content of the NAR with the given id
Calls GET /nifi-api/controller/nar-manager/nars/{id}/content.
Parameters
id: The id of the NAR.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn get_flow_analysis_rule_property_descriptor(
&self,
id: &str,
property_name: &str,
sensitive: Option<bool>,
) -> Result<PropertyDescriptorDto, NifiError>
pub async fn get_flow_analysis_rule_property_descriptor( &self, id: &str, property_name: &str, sensitive: Option<bool>, ) -> Result<PropertyDescriptorDto, NifiError>
Gets a flow analysis rule property descriptor
Calls GET /nifi-api/controller/flow-analysis-rules/{id}/descriptors.
Parameters
id: The flow analysis rule id.property_name: The property name.sensitive: Property Descriptor requested sensitive status
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /flow-analysis-rules/{uuid}.
Sourcepub async fn get_property_descriptor(
&self,
id: &str,
property_name: &str,
sensitive: Option<bool>,
) -> Result<PropertyDescriptorDto, NifiError>
pub async fn get_property_descriptor( &self, id: &str, property_name: &str, sensitive: Option<bool>, ) -> Result<PropertyDescriptorDto, NifiError>
Gets a flow registry client property descriptor
Calls GET /nifi-api/controller/registry-clients/{id}/descriptors.
Parameters
id: The flow registry client id.property_name: The property name.sensitive: Property Descriptor requested sensitive status
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller/registry-clients/{id}.
Sourcepub async fn get_nar_details(
&self,
id: &str,
) -> Result<NarDetailsEntity, NifiError>
pub async fn get_nar_details( &self, id: &str, ) -> Result<NarDetailsEntity, NifiError>
Retrieves the component types available from the installed NARs
Calls GET /nifi-api/controller/nar-manager/nars/{id}/details.
Parameters
id: The id of the NAR.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read - /controller.
Sourcepub async fn update_run_status(
&self,
id: &str,
body: &FlowAnalysisRuleRunStatusEntity,
) -> Result<FlowAnalysisRuleEntity, NifiError>
pub async fn update_run_status( &self, id: &str, body: &FlowAnalysisRuleRunStatusEntity, ) -> Result<FlowAnalysisRuleEntity, NifiError>
Updates run status of a flow analysis rule
Calls PUT /nifi-api/controller/flow-analysis-rules/{id}/run-status.
Parameters
id: The flow analysis rule id.body: The flow analysis rule run status.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /flow-analysis-rules/{uuid} or or /operation/flow-analysis-rules/{uuid}.
Sourcepub async fn get_flow_analysis_rule_state(
&self,
id: &str,
) -> Result<ComponentStateDto, NifiError>
pub async fn get_flow_analysis_rule_state( &self, id: &str, ) -> Result<ComponentStateDto, NifiError>
Gets the state for a flow analysis rule
Calls GET /nifi-api/controller/flow-analysis-rules/{id}/state.
Parameters
id: The flow analysis rule id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /flow-analysis-rules/{uuid}.
Sourcepub async fn clear_state(
&self,
id: &str,
body: &ComponentStateEntity,
) -> Result<ComponentStateDto, NifiError>
pub async fn clear_state( &self, id: &str, body: &ComponentStateEntity, ) -> Result<ComponentStateDto, NifiError>
Clears the state for a flow analysis rule
Calls POST /nifi-api/controller/flow-analysis-rules/{id}/state/clear-requests.
Parameters
id: The flow analysis rule id.body: Optional component state to perform a selective key removal. If omitted, clears all state.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write - /flow-analysis-rules/{uuid}.