pub struct FlowFileQueues<'a> { /* private fields */ }Implementations
Sourceimpl<'a> FlowFileQueues<'a>
impl<'a> FlowFileQueues<'a>
Sourcepub async fn create_drop_request(
&self,
id: &str,
) -> Result<DropRequestDto, NifiError>
pub async fn create_drop_request( &self, id: &str, ) -> Result<DropRequestDto, NifiError>
Creates a request to drop the contents of the queue in this connection.
Calls POST /nifi-api/flowfile-queues/{id}/drop-requests.
Parameters
id: The connection id.
Returns
202: The request has been accepted. A HTTP response header will contain the URI where the response can be polled.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write Source Data - /data/{component-type}/{uuid}.
Sourcepub async fn remove_drop_request(
&self,
id: &str,
drop_request_id: &str,
) -> Result<DropRequestDto, NifiError>
pub async fn remove_drop_request( &self, id: &str, drop_request_id: &str, ) -> Result<DropRequestDto, NifiError>
Cancels and/or removes a request to drop the contents of this connection.
Calls DELETE /nifi-api/flowfile-queues/{id}/drop-requests/{drop-request-id}.
Parameters
id: The connection id.drop_request_id: The drop request id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write Source Data - /data/{component-type}/{uuid}.
Sourcepub async fn get_drop_request(
&self,
id: &str,
drop_request_id: &str,
) -> Result<DropRequestDto, NifiError>
pub async fn get_drop_request( &self, id: &str, drop_request_id: &str, ) -> Result<DropRequestDto, NifiError>
Gets the current status of a drop request for the specified connection.
Calls GET /nifi-api/flowfile-queues/{id}/drop-requests/{drop-request-id}.
Parameters
id: The connection id.drop_request_id: The drop request id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Write Source Data - /data/{component-type}/{uuid}.
Sourcepub async fn get_flow_file(
&self,
id: &str,
flowfile_uuid: &str,
cluster_node_id: Option<&str>,
) -> Result<FlowFileDto, NifiError>
pub async fn get_flow_file( &self, id: &str, flowfile_uuid: &str, cluster_node_id: Option<&str>, ) -> Result<FlowFileDto, NifiError>
Gets a FlowFile from a Connection.
Calls GET /nifi-api/flowfile-queues/{id}/flowfiles/{flowfile-uuid}.
Parameters
id: The connection id.flowfile_uuid: The flowfile uuid.cluster_node_id: The id of the node where the content exists if clustered.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read Source Data - /data/{component-type}/{uuid}.
Sourcepub async fn download_flow_file_content(
&self,
id: &str,
flowfile_uuid: &str,
client_id: Option<&str>,
cluster_node_id: Option<&str>,
range: Option<&str>,
) -> Result<Vec<u8>, NifiError>
pub async fn download_flow_file_content( &self, id: &str, flowfile_uuid: &str, client_id: Option<&str>, cluster_node_id: Option<&str>, range: Option<&str>, ) -> Result<Vec<u8>, NifiError>
Gets the content for a FlowFile in a Connection.
Calls GET /nifi-api/flowfile-queues/{id}/flowfiles/{flowfile-uuid}/content.
Parameters
id: The connection id.flowfile_uuid: The flowfile uuid.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.cluster_node_id: The id of the node where the content exists if clustered.
Returns
206: Partial Content with range of bytes requested
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.416: Requested Range Not Satisfiable based on bytes requested
Permissions
Requires Read Source Data - /data/{component-type}/{uuid}.
Sourcepub async fn download_flow_file_content_stream(
&self,
id: &str,
flowfile_uuid: &str,
client_id: Option<&str>,
cluster_node_id: Option<&str>,
range: Option<&str>,
) -> Result<BytesStream, NifiError>
pub async fn download_flow_file_content_stream( &self, id: &str, flowfile_uuid: &str, client_id: Option<&str>, cluster_node_id: Option<&str>, range: Option<&str>, ) -> Result<BytesStream, NifiError>
Streaming variant: yields body chunks as they arrive instead of buffering the whole response.
Gets the content for a FlowFile in a Connection.
Calls GET /nifi-api/flowfile-queues/{id}/flowfiles/{flowfile-uuid}/content.
Parameters
id: The connection id.flowfile_uuid: The flowfile uuid.client_id: If the client id is not specified, new one will be generated. This value (whether specified or generated) is included in the response.cluster_node_id: The id of the node where the content exists if clustered.
Returns
206: Partial Content with range of bytes requested
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.416: Requested Range Not Satisfiable based on bytes requested
Permissions
Requires Read Source Data - /data/{component-type}/{uuid}.
Sourcepub async fn create_flow_file_listing(
&self,
id: &str,
) -> Result<ListingRequestDto, NifiError>
pub async fn create_flow_file_listing( &self, id: &str, ) -> Result<ListingRequestDto, NifiError>
Lists the contents of the queue in this connection.
Calls POST /nifi-api/flowfile-queues/{id}/listing-requests.
Parameters
id: The connection id.
Returns
202: The request has been accepted. A HTTP response header will contain the URI where the response can be polled.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read Source Data - /data/{component-type}/{uuid}.
Sourcepub async fn delete_listing_request(
&self,
id: &str,
listing_request_id: &str,
) -> Result<ListingRequestDto, NifiError>
pub async fn delete_listing_request( &self, id: &str, listing_request_id: &str, ) -> Result<ListingRequestDto, NifiError>
Cancels and/or removes a request to list the contents of this connection.
Calls DELETE /nifi-api/flowfile-queues/{id}/listing-requests/{listing-request-id}.
Parameters
id: The connection id.listing_request_id: The listing request id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read Source Data - /data/{component-type}/{uuid}.
Sourcepub async fn get_listing_request(
&self,
id: &str,
listing_request_id: &str,
) -> Result<ListingRequestDto, NifiError>
pub async fn get_listing_request( &self, id: &str, listing_request_id: &str, ) -> Result<ListingRequestDto, NifiError>
Gets the current status of a listing request for the specified connection.
Calls GET /nifi-api/flowfile-queues/{id}/listing-requests/{listing-request-id}.
Parameters
id: The connection id.listing_request_id: The listing request id.
Errors
400: NiFi was unable to complete the request because it was invalid. The request should not be retried without modification.401: Client could not be authenticated.403: Client is not authorized to make this request.404: The specified resource could not be found.409: The request was valid but NiFi was not in the appropriate state to process it.
Permissions
Requires Read Source Data - /data/{component-type}/{uuid}.